@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: UTF-8 -*-
-# Copyright (c) 2016, wradlib developers.
+# Copyright (c) 2011-2018, wradlib developers.
 # Distributed under the MIT License. See LICENSE.txt for more info.
 
 """
@@ -18,16 +18,16 @@ Please note that the actual application of polarimetric moments is implemented
 in the corresponding wradlib modules, e.g.:
 
     - fuzzy echo classification from polarimetric moments
-      (:meth:`wradlib.clutter.classify_echo_fuzzy`)
-    - attenuation correction (:meth:`wradlib.atten.pia_from_kdp`)
-    - direct precipitation retrieval from Kdp (:meth:`wradlib.trafo.kdp2r`)
+      (:func:`wradlib.clutter.classify_echo_fuzzy`)
+    - attenuation correction (:func:`wradlib.atten.pia_from_kdp`)
+    - direct precipitation retrieval from Kdp (:func:`wradlib.trafo.kdp_to_r`)
 
 Establishing a valid :math:`Phi_{DP}` profile for :math:`K_{DP}` retrieval
 involves despeckling (linear_despeckle), phase unfolding, and iterative
 retrieval of :math:`Phi_{DP}` form :math:`K_{DP}`.
 The main workflow and its single steps is based on a publication by
 :cite:`Vulpiani2012`. For convenience, the entire workflow has been
-put together in the function :meth:`wradlib.dp.process_raw_phidp_vulpiani`.
+put together in the function :func:`wradlib.dp.process_raw_phidp_vulpiani`.
 
 Once a valid :math:`Phi_{DP}` profile has been established, the
 `kdp_from_phidp` functions can be used to retrieve :math:`K_{DP}`.
@@ -44,10 +44,7 @@ all input arrays.
    :toctree: generated/
 
     process_raw_phidp_vulpiani
-    kdp_from_phidp_finitediff
-    kdp_from_phidp_linregress
-    kdp_from_phidp_convolution
-    kdp_from_phidp_sobel
+    kdp_from_phidp
     unfold_phi_vulpiani
     unfold_phi
     linear_despeckle
@@ -57,14 +54,13 @@ all input arrays.
 
 import numpy as np
 from scipy.interpolate import interp1d
-from scipy.signal import medfilt
 from scipy.stats import linregress
 from scipy.ndimage.filters import convolve1d
 from . import util as util
 
 
-def process_raw_phidp_vulpiani(phidp, dr, N_despeckle=5, L=7,
-                               niter=2, copy=False):
+def process_raw_phidp_vulpiani(phidp, dr, ndespeckle=5, winlen=7,
+                               niter=2, copy=False, **kwargs):
     """Establish consistent :math:`Phi_{DP}` profiles from raw data.
 
     This approach is based on :cite:`Vulpiani2012` and involves a
@@ -83,37 +79,40 @@ def process_raw_phidp_vulpiani(phidp, dr, N_despeckle=5, L=7,
     ----------
     phidp : array
         array of shape (n azimuth angles, n range gates)
-    dr : gate length in km
-    N_despeckle : integer
-        *N* parameter of function dp.linear_despeckle
-    L : integer
-        *L* parameter of :meth:`~wradlib.dp.kdp_from_phidp_convolution`
-    niter : integer
-        Number of iterations in which phidp is retrieved from kdp
-        and vice versa
-    copy : boolean
-        if True, the original phidp array will remain unchanged
+    dr : float
+        gate length in km
+    ndespeckle : int
+        ``ndespeckle`` parameter of :func:`~wradlib.dp.linear_despeckle`
+    winlen : integer
+        ``winlen`` parameter of :func:`~wradlib.dp.kdp_from_phidp`
+    niter : int
+        Number of iterations in which :math:`Phi_{DP}` is retrieved from
+        :math:`K_{DP}` and vice versa
+    copy : bool
+        if True, the original :math:`Phi_{DP}` array will remain unchanged
 
     Returns
     -------
-    phidp : array of shape (n azimuth angles, n range gates)
-        reconstructed phidp
-    kdp : array of shape (n azimuth angles, n range gates)
-        kdp estimate corresponding to phidp output
+    phidp : :class:`numpy:numpy.ndarray`
+        array of shape (n azimuth angles, n range gates) reconstructed
+        :math:`Phi_{DP}`
+    kdp : :class:`numpy:numpy.ndarray`
+        array of shape (n azimuth angles, n range gates)
+        ``kdp`` estimate corresponding to ``phidp`` output
 
     Examples
     --------
 
-    See :ref:`notebooks/verification/wradlib_verify_example.ipynb`.
+    See :ref:`/notebooks/verification/wradlib_verify_example.ipynb`.
 
     """
     if copy:
         phidp = phidp.copy()
 
     # despeckle
-    phidp = linear_despeckle(phidp, N_despeckle)
+    phidp = linear_despeckle(phidp, ndespeckle)
     # kdp retrieval first guess
-    kdp = kdp_from_phidp_convolution(phidp, dr=dr, L=L)
+    kdp = kdp_from_phidp(phidp, dr=dr, winlen=winlen, **kwargs)
     # remove extreme values
     kdp[kdp > 20] = 0
     kdp[np.logical_and(kdp < -2, kdp > -20)] = 0
@@ -125,7 +124,7 @@ def process_raw_phidp_vulpiani(phidp, dr, N_despeckle=5, L=7,
     phidp[phidp > 360] = np.nan
 
     # kdp retrieval second guess
-    kdp = kdp_from_phidp_convolution(phidp, dr=dr, L=L)
+    kdp = kdp_from_phidp(phidp, dr=dr, winlen=winlen, **kwargs)
     kdp = _fill_sweep(kdp)
 
     # remove remaining extreme values
@@ -137,7 +136,7 @@ def process_raw_phidp_vulpiani(phidp, dr, N_despeckle=5, L=7,
         # phidp from kdp through integration
         phidp = 2 * np.cumsum(kdp, axis=-1) * dr
         # kdp from phidp by convolution
-        kdp = kdp_from_phidp_convolution(phidp, dr=dr, L=L)
+        kdp = kdp_from_phidp(phidp, dr=dr, winlen=winlen, **kwargs)
         # convert all NaNs to zeros (normally, this line can be assumed
         # to be redundant)
         kdp = _fill_sweep(kdp)
@@ -146,15 +145,17 @@ def process_raw_phidp_vulpiani(phidp, dr, N_despeckle=5, L=7,
 
 
 def unfold_phi_vulpiani(phidp, kdp):
-    """Alternative phase unfolding which completely relies on Kdp.
+    """Alternative phase unfolding which completely relies on :math:`K_{DP}`.
 
     This unfolding should be used in oder to iteratively reconstruct
-    phidp and Kdp (see :cite:`Vulpiani2012`).
+    :math:`Phi_{DP}` and :math:`K_{DP}` (see :cite:`Vulpiani2012`).
 
     Parameters
     ----------
-    phidp : array of floats
-    kdp : array of floats
+    phidp : :class:`numpy:numpy.ndarray`
+        array of floats
+    kdp : :class:`numpy:numpy.ndarray`
+        array of floats
 
     """
     # unfold phidp
@@ -174,11 +175,12 @@ def unfold_phi_vulpiani(phidp, kdp):
 
 
 def _fill_sweep(dat, kind="nan_to_num", fill_value=0.):
-    """Fills missing data in a 1d profile
+    """Fills missing data in a 1D profile.
 
     Parameters
     ----------
-    dat : array of shape (n azimuth angles, n range gates)
+    dat : :class:`numpy:numpy.ndarray`
+        array of shape (n azimuth angles, n range gates)
     kind : string
         Defines how the filling is done.
     fill_value : float
@@ -207,52 +209,29 @@ def _fill_sweep(dat, kind="nan_to_num", fill_value=0.):
     return dat.reshape(shape)
 
 
-def kdp_from_phidp_finitediff(phidp, L=7, dr=1.):
-    """Retrieves :math:`K_{DP}` from :math:`Phi_{DP}` by applying a moving
-    window range finite difference derivative.
+def kdp_from_phidp(phidp, winlen=7, dr=1., method=None):
+    """Retrieves :math:`K_{DP}` from :math:`Phi_{DP}`.
 
-    See :cite:`Vulpiani2012` for details about this approach.
+    In normal operation the method uses convolution to estimate :math:`K_{DP}`
+    (the derivative of :math:`Phi_{DP}` with Low-noise Lanczos differentiators.
+    The results are very similar to the fallback moving window linear
+    regression (`method=slow`), but the former is *much* faster, depending on
+    the percentage of NaN values in the beam, though.
 
-    Please note that the moving window size *L* is specified as the number of
+    For further reading please see `Differentiation by integration using \
+    orthogonal polynomials, a survey <https://arxiv.org/pdf/1102.5219>`_ \
+    and `Low-noise Lanczos differentiators \
+    <http://www.holoborodko.com/pavel/numerical-methods/numerical-derivative/\
+lanczos-low-noise-differentiators/>`_.
+
+    The fast method provides fast :math:`K_{DP}` retrieval but will return NaNs
+    in case at least one value in the moving window is NaN. The remaining gates
+    are treated by using local linear regression where possible.
+
+    Please note that the moving window size ``winlen`` is specified as the number of
     range gates. Thus, this argument might need adjustment in case the
     range resolution changes.
-    In the original publication (:cite:`Vulpiani2012`), the value L=7 was
-    chosen for a range resolution of 1km.
-
-    Warning
-    -------
-    The function is designed for speed by allowing to process
-    multiple dimensions in one step. For this purpose, the RANGE dimension
-    needs to be the LAST dimension of the input array.
-
-    Parameters
-    ----------
-    phidp : multi-dimensional array
-        Note that the range dimension must be the last dimension of
-        the input array.
-    L : integer
-        Width of the window (as number of range gates)
-    dr : gate length in km
-    """
-    assert (L % 2) == 1, \
-        "Window size N for function kdp_from_phidp must be an odd number."
-    # Make really sure L is an integer
-    L = int(L)
-    kdp = np.zeros(phidp.shape)
-    for r in range(int(L / 2), phidp.shape[-1] - int(L / 2)):
-        kdp[..., r] = (phidp[..., r + int(L / 2)] -
-                       phidp[..., r - int(L / 2)]) / (L - 1)
-    return kdp / 2. / dr
-
-
-def kdp_from_phidp_linregress(phidp, L=7, dr=1.):
-    """Alternative :math:`K_{DP}` from :math:`Phi_{DP}` by applying a moving
-    window linear regression.
-
-    Please note that the moving window size *L* is specified as the number of
-    range gates. Thus, this argument might need adjustment in case the range
-    resolution changes.
-    In the original publication (:cite:`Vulpiani2012`), the value L=7
+    In the original publication (:cite:`Vulpiani2012`), the value ``winlen=7``
     was chosen for a range resolution of 1km.
 
     Warning
@@ -263,231 +242,16 @@ def kdp_from_phidp_linregress(phidp, L=7, dr=1.):
 
     Parameters
     ----------
-    phidp : multi-dimensional array
-        Note that the range dimension must be the last dimension of the
-        input array.
-    L : integer
+    phidp : :class:`numpy:numpy.ndarray`
+        multi-dimensional array, note that the range dimension must be the
+        last dimension of the input array.
+    winlen : int
         Width of the window (as number of range gates)
-    dr : gate length in km
-
-    Examples
-    --------
-    >>> import wradlib
-    >>> import numpy as np
-    >>> import pylab as pl
-    >>> pl.interactive(True)
-    >>> kdp_true = np.sin(3 * np.arange(0, 10, 0.1))
-    >>> phidp_true = np.cumsum(kdp_true)
-    >>> phidp_raw = phidp_true + np.random.uniform(-1, 1, len(phidp_true))
-    >>> gaps = np.concatenate([range(10, 20), range(30, 40), range(60, 80)])
-    >>> phidp_raw[gaps] = np.nan
-    >>> kdp_re = wradlib.dp.kdp_from_phidp_linregress(phidp_raw)
-    >>> line1 = pl.plot(np.ma.masked_invalid(phidp_true), "b--", label="phidp_true")  # noqa
-    >>> line2 = pl.plot(np.ma.masked_invalid(phidp_raw), "b-", label="phidp_raw")  # noqa
-    >>> line3 = pl.plot(kdp_true, "g-", label="kdp_true")
-    >>> line4 = pl.plot(np.ma.masked_invalid(kdp_re), "r-", label="kdp_reconstructed")  # noqa
-    >>> lgnd = pl.legend(("phidp_true", "phidp_raw", "kdp_true", "kdp_reconstructed"))  # noqa
-
-    """
-    assert (L % 2) == 1, \
-        "Window size N for function kdp_from_phidp must be an odd number."
-
-    shape = phidp.shape
-    phidp = phidp.reshape((-1, shape[-1]))
-
-    # Make really sure L is an integer
-    L = int(L)
-
-    x = np.arange(phidp.shape[-1])
-    valids = ~np.isnan(phidp)
-    kdp = np.zeros(phidp.shape) * np.nan
-
-    for beam in range(len(phidp)):
-        for r in range(int(L / 2), phidp.shape[-1] - int(L / 2)):
-            # iterate over gates
-            ix = np.arange(r - L / 2, r + L / 2 + 1, dtype=np.int)
-            if np.sum(valids[beam, ix]) < L / 2:
-                # not enough valid values inside our window
-                continue
-            kdp[beam, r] = linregress(x[ix][valids[beam, ix]],
-                                      phidp[beam, ix[valids[beam, ix]]])[0]
-        # take care of the start and end of the beam
-        #   start
-        ix = np.arange(0, L)
-        if np.sum(valids[beam, ix]) >= L / 2:
-            kdp[beam, ix] = linregress(x[ix][valids[beam, ix]],
-                                       phidp[beam, ix[valids[beam, ix]]])[0]
-        # end
-        ix = np.arange(shape[-1] - L, shape[-1])
-        if np.sum(valids[beam, ix]) >= L / 2:
-            kdp[beam, ix] = linregress(x[ix][valids[beam, ix]],
-                                       phidp[beam, ix[valids[beam, ix]]])[0]
-
-    # accounting for forward/backward propagation AND gate length
-    return kdp.reshape(shape) / 2. / dr
-
-
-def kdp_from_phidp_sobel(phidp, L=7, dr=1.):
-    """Alternative :math:`K_{DP}` from :math:`Phi_{DP}` by applying a sobel
-    filter where possible and linear regression otherwise.
-
-    The results are quite similar to the moving window linear regression, but
-    this is much faster, depending on the percentage of NaN values in the beam,
-    though. The Sobel filter is applied everywhere but will return NaNs in case
-    only one value in the moving window is NaN. The remaining NaN values are
-    then dealt with by using local linear regression
-    (see :meth:`~wradlib.dp.kdp_from_phidp_linregress`).
-
-    This Sobel filter solution has been provided by Scott Collis at
-    StackOverflow :cite:`Sobel-linfit`
-
-    Please note that the moving window size *L* is specified as the number of
-    range gates. Thus, this argument might need adjustment in case the range
-    resolution changes.
-    In the original publication (:cite:`Vulpiani2012`), the value L=7
-    was chosen for a range resolution of 1km.
-
-    Warning
-    -------
-    The function is designed for speed by allowing to process
-    multiple dimensions in one step. For this purpose, the RANGE dimension
-    needs to be the LAST dimension of the input array.
-
-    Parameters
-    ----------
-    phidp : multi-dimensional array
-        Note that the range dimension must be the last dimension of the
-        input array.
-    L : integer
-        Width of the window (as number of range gates)
-    dr : gate length in km
-
-    Examples
-    --------
-    >>> import wradlib
-    >>> import numpy as np
-    >>> import pylab as pl
-    >>> pl.interactive(True)
-    >>> kdp_true = np.sin(3 * np.arange(0, 10, 0.1))
-    >>> phidp_true = np.cumsum(kdp_true)
-    >>> phidp_raw = phidp_true + np.random.uniform(-1, 1, len(phidp_true))
-    >>> gaps = np.concatenate([range(10, 20), range(30, 40), range(60, 80)])
-    >>> phidp_raw[gaps] = np.nan
-    >>> kdp_re = wradlib.dp.kdp_from_phidp_linregress(phidp_raw)
-    >>> line1 = pl.plot(np.ma.masked_invalid(phidp_true), "b--", label="phidp_true")  # noqa
-    >>> line2 = pl.plot(np.ma.masked_invalid(phidp_raw), "b-", label="phidp_raw")  # noqa
-    >>> line3 = pl.plot(kdp_true, "g-", label="kdp_true")
-    >>> line4 = pl.plot(np.ma.masked_invalid(kdp_re), "r-", label="kdp_reconstructed")  # noqa
-    >>> lgnd = pl.legend(("phidp_true", "phidp_raw", "kdp_true", "kdp_reconstructed"))  # noqa
-
-    """
-    assert (L % 2) == 1, \
-        "Window size N for function kdp_from_phidp must be an odd number."
-
-    shape = phidp.shape
-    phidp = phidp.reshape((-1, shape[-1]))
-
-    # Make really sure L is an integer
-    L = int(L)
-
-    kdp = np.zeros(phidp.shape) * np.nan
-
-    # do it fast using the sobel filter
-    for beam in range(len(phidp)):
-        kdp[beam, :] = sobel(phidp[beam, :], window_len=L)
-
-    # find remaining NaN values with valid neighbours
-    x = np.arange(phidp.shape[-1])
-    invalidkdp = np.isnan(kdp)
-    validphidp = ~np.isnan(phidp)
-    kernel = np.ones(L, dtype="i4")
-    # and do the slow moving window linear regression
-    for beam in range(len(phidp)):
-        # number of valid neighbours around one gate
-        nvalid = np.convolve(validphidp[beam], kernel, "same") > L / 2
-        # find those gates which have invalid Kdp AND enough valid neighbours
-        nangates = np.where(invalidkdp[beam] & nvalid)[0]
-        # now iterate over those
-        for r in nangates:
-            ix = np.arange(min(0, r - L / 2), max(shape[-1], r + L / 2 + 1))
-            # check again (just to make sure...)
-            if np.sum(validphidp[beam, ix]) < L / 2:
-                # not enough valid values inside our window
-                continue
-            kdp[beam, r] = linregress(x[ix][validphidp[beam, ix]],
-                                      phidp[beam,
-                                            ix[validphidp[beam, ix]]])[0]
-        # take care of the start and end of the beam
-        #   start
-        ix = np.arange(0, L)
-        if np.sum(validphidp[beam, ix]) >= L / 2:
-            kdp[beam, ix] = linregress(x[ix][validphidp[beam, ix]],
-                                       phidp[beam,
-                                             ix[validphidp[beam, ix]]])[0]
-        # end
-        ix = np.arange(shape[-1] - L, shape[-1])
-        if np.sum(validphidp[beam, ix]) >= L / 2:
-            kdp[beam, ix] = linregress(x[ix][validphidp[beam, ix]],
-                                       phidp[beam,
-                                             ix[validphidp[beam, ix]]])[0]
-
-    # accounting for forward/backward propagation AND gate length
-    return kdp.reshape(shape) / 2. / dr
-
-
-def sobel(x, window_len=7):
-    """Sobel differential filter for calculating KDP.
-
-    This solution has been taken from StackOverflow :cite:`Sobel-linfit`
-
-    Returns
-    -------
-    output : differential signal (unscaled for gate spacing)
-
-    """
-    s = np.r_[x[window_len - 1:0:-1], x, x[-1:-window_len:-1]]
-    w = 2.0 * np.arange(window_len) / (window_len - 1.0) - 1.0
-    w = w / (abs(w).sum())
-    y = np.convolve(w, s, mode='valid')
-    return (-1.0 * y[int(window_len / 2):len(x) + int(window_len / 2)] /
-            (window_len / 3.0))
-
-
-def kdp_from_phidp_convolution(phidp, L=7, dr=1.):
-    """Alternative :math:`K_{DP}` from :math:`Phi_{DP}` by applying a
-    convolution filter where possible and linear regression otherwise.
-
-    The results are very similar to the moving window linear regression, but
-    the convolution is *much* faster, depending on the percentage of NaN values
-    in the beam, though.
-
-    The convolution filter was suggested by Kai Mühlbauer (University of Bonn).
-
-    The filter provides fast :math:`K_{DP}` retrieval but will return NaNs in
-    case at least one value in the moving window is NaN. The remaining gates
-    are treated by using local linear regression where possible
-    (see :meth:`~wradlib.dp.kdp_from_phidp_linregress`).
-
-    Please note that the moving window size *L* is specified as the number of
-    range gates. Thus, this argument might need adjustment in case the
-    range resolution changes.
-    In the original publication (:cite:`Vulpiani2012`), the value L=7
-    was chosen for a range resolution of 1km.
-
-    Warning
-    -------
-    The function is designed for speed by allowing to process
-    multiple dimensions in one step. For this purpose, the RANGE dimension
-    needs to be the LAST dimension of the input array.
-
-    Parameters
-    ----------
-    phidp : multi-dimensional array
-        Note that the range dimension must be the last dimension of the
-        input array.
-    L : integer
-        Width of the window (as number of range gates)
-    dr : gate length in km
+    dr : float
+        gate length in km
+    method : str
+        If None uses fast convolution based differentiation, if 'slow' uses
+        linear regression.
 
     Examples
     --------
@@ -501,28 +265,28 @@ def kdp_from_phidp_convolution(phidp, L=7, dr=1.):
     >>> phidp_raw = phidp_true + np.random.uniform(-1, 1, len(phidp_true))
     >>> gaps = np.concatenate([range(10, 20), range(30, 40), range(60, 80)])
     >>> phidp_raw[gaps] = np.nan
-    >>> kdp_re = wradlib.dp.kdp_from_phidp_linregress(phidp_raw)
+    >>> kdp_re = wradlib.dp.kdp_from_phidp(phidp_raw)
     >>> line1 = pl.plot(np.ma.masked_invalid(phidp_true), "b--", label="phidp_true")  # noqa
     >>> line2 = pl.plot(np.ma.masked_invalid(phidp_raw), "b-", label="phidp_raw")  # noqa
     >>> line3 = pl.plot(kdp_true, "g-", label="kdp_true")
     >>> line4 = pl.plot(np.ma.masked_invalid(kdp_re), "r-", label="kdp_reconstructed")  # noqa
     >>> lgnd = pl.legend(("phidp_true", "phidp_raw", "kdp_true", "kdp_reconstructed"))  # noqa
     >>> pl.show()
-
     """
-    assert (L % 2) == 1, \
+    assert (winlen % 2) == 1, \
         "Window size N for function kdp_from_phidp must be an odd number."
 
     shape = phidp.shape
     phidp = phidp.reshape((-1, shape[-1]))
 
-    # Make really sure L is an integer
-    L = int(L)
+    # Make really sure winlen is an integer
+    winlen = int(winlen)
 
-    window = 2. * np.arange(L) / (L - 1.0) - 1.0
-    window = window / (abs(window).sum())
-    window = window[::-1]
-    kdp = convolve1d(phidp, window, axis=1) / (len(window) / 3.0)
+    if method == 'slow':
+        kdp = np.zeros(phidp.shape) * np.nan
+    else:
+        window = lanczos_differentiator(winlen)
+        kdp = convolve1d(phidp, window, axis=1)
 
     # find remaining NaN values with valid neighbours
     invalidkdp = np.isnan(kdp)
@@ -532,47 +296,54 @@ def kdp_from_phidp_convolution(phidp, L=7, dr=1.):
 
     # Otherwise continue
     x = np.arange(phidp.shape[-1])
-    validphidp = ~np.isnan(phidp)
-    kernel = np.ones(L, dtype="i4")
+    valids = ~np.isnan(phidp)
+    kernel = np.ones(winlen, dtype="i4")
     # and do the slow moving window linear regression
     for beam in range(len(phidp)):
         # number of valid neighbours around one gate
-        nvalid = np.convolve(validphidp[beam], kernel, "same") > L / 2
+        nvalid = np.convolve(valids[beam], kernel, "same") > winlen / 2
         # find those gates which have invalid Kdp AND enough valid neighbours
         nangates = np.where(invalidkdp[beam] & nvalid)[0]
         # now iterate over those
         for r in nangates:
-            ix = np.arange(max(0, r - int(L / 2)),
-                           min(r + int(L / 2) + 1, shape[-1]))
+            ix = np.arange(max(0, r - int(winlen / 2)),
+                           min(r + int(winlen / 2) + 1, shape[-1]))
             # check again (just to make sure...)
-            if np.sum(validphidp[beam, ix]) < L / 2:
+            if np.sum(valids[beam, ix]) < winlen / 2:
                 # not enough valid values inside our window
                 continue
-            kdp[beam, r] = linregress(x[ix][validphidp[beam, ix]],
-                                      phidp[beam, ix[validphidp[beam, ix]]])[0]
+            kdp[beam, r] = linregress(x[ix][valids[beam, ix]],
+                                      phidp[beam, ix[valids[beam, ix]]])[0]
         # take care of the start and end of the beam
         #   start
-        ix = np.arange(0, L)
-        if np.sum(validphidp[beam, ix]) >= 2:
-            kdp[beam, 0:int(L / 2)] = linregress(x[ix][validphidp[beam, ix]],
-                                                 phidp[beam,
-                                                       ix[validphidp[beam,
-                                                                     ix]]])[0]
+        ix = np.arange(0, winlen)
+        if np.sum(valids[beam, ix]) >= 2:
+            kdp[beam, 0:int(winlen / 2)] = linregress(x[ix][valids[beam, ix]],
+                                                      phidp[beam,
+                                                            ix[valids[beam,
+                                                                      ix]]])[0]
         # end
-        ix = np.arange(shape[-1] - L, shape[-1])
-        if np.sum(validphidp[beam, ix]) >= 2:
-            kdp[beam, -int(L / 2):] = linregress(x[ix][validphidp[beam, ix]],
-                                                 phidp[beam,
-                                                       ix[validphidp[beam,
-                                                                     ix]]])[0]
+        ix = np.arange(shape[-1] - winlen, shape[-1])
+        if np.sum(valids[beam, ix]) >= 2:
+            kdp[beam, -int(winlen / 2):] = linregress(x[ix][valids[beam, ix]],
+                                                      phidp[beam,
+                                                            ix[valids[beam,
+                                                                      ix]]])[0]
 
     # accounting for forward/backward propagation AND gate length
     return kdp.reshape(shape) / 2. / dr
 
 
+def lanczos_differentiator(winlen):
+    m = (winlen - 1) / 2
+    denom = m * (m + 1.) * (2 * m + 1.)
+    k = np.arange(1, m + 1)
+    f = 3 * k / denom
+    return np.r_[f[::-1], [0], -f]
+
+
 def unfold_phi(phidp, rho, width=5, copy=False):
-    """
-    Unfolds differential phase by adjusting values that exceeded maximum
+    """Unfolds differential phase by adjusting values that exceeded maximum \
     ambiguous range.
 
     Accepts arbitrarily dimensioned arrays, but THE LAST DIMENSION MUST BE
@@ -584,12 +355,15 @@ def unfold_phi(phidp, rho, width=5, copy=False):
 
     Parameters
     ----------
-    phidp : array of shape (...,nr) with nr being the number of range bins
-    rho : array of same shape as phidp
-    width : integer
+    phidp : :class:`numpy:numpy.ndarray`
+        array of shape (...,nr) with nr being the number of range bins
+    rho : :class:`numpy:numpy.ndarray`
+        array of same shape as ``phidp``
+    width : int
        Width of the analysis window
-    copy : boolean
-       Leaves original phidp array unchanged if set to True (default: False)
+    copy : bool
+       Leaves original ``phidp`` array unchanged if set to True
+       (default: False)
     """
     # Check whether fast Fortran implementation is available
     speedup = util.import_optional("wradlib.speedup")
@@ -601,7 +375,7 @@ def unfold_phi(phidp, rho, width=5, copy=False):
     if copy:
         phidp = phidp.copy()
     rho = rho.reshape((-1, shape[-1]))
-    gradphi = gradient_from_smoothed(phidp)
+    gradphi = util.gradient_from_smoothed(phidp)
 
     beams, rs = phidp.shape
 
@@ -620,8 +394,7 @@ def unfold_phi(phidp, rho, width=5, copy=False):
 
 
 def unfold_phi_naive(phidp, rho, width=5, copy=False):
-    """
-    Unfolds differential phase by adjusting values that exceeded maximum
+    """Unfolds differential phase by adjusting values that exceeded maximum \
     ambiguous range.
 
     Accepts arbitrarily dimensioned arrays, but THE LAST DIMENSION MUST BE
@@ -633,12 +406,15 @@ def unfold_phi_naive(phidp, rho, width=5, copy=False):
 
     Parameters
     ----------
-    phidp : array of shape (...,nr) with nr being the number of range bins
-    rho : array of same shape as phidp
-    width : integer
+    phidp : :class:`numpy:numpy.ndarray`
+        array of shape (...,nr) with nr being the number of range bins
+    rho : :class:`numpy:numpy.ndarray`
+        array of same shape as ``phidp``
+    width : int
        Width of the analysis window
-    copy : boolean
-       Leaves original phidp array unchanged if set to True (default: False)
+    copy : bool
+        Leaves original ``phidp`` array unchanged if set to True
+        (default: False)
 
     """
     shape = phidp.shape
@@ -648,7 +424,7 @@ def unfold_phi_naive(phidp, rho, width=5, copy=False):
     if copy:
         phidp = phidp.copy()
     rho = rho.reshape((-1, shape[-1]))
-    gradphi = gradient_from_smoothed(phidp)
+    gradphi = util.gradient_from_smoothed(phidp)
 
     beams, rs = phidp.shape
 
@@ -684,7 +460,7 @@ def unfold_phi_naive(phidp, rho, width=5, copy=False):
     return phidp
 
 
-def linear_despeckle(data, N=3, copy=False):
+def linear_despeckle(data, ndespeckle=3, copy=False):
     """Remove floating pixels in between NaNs in a multi-dimensional array.
 
     Warning
@@ -694,19 +470,18 @@ def linear_despeckle(data, N=3, copy=False):
 
     Parameters
     ----------
-    data : multi-dimensional array
+    data : :class:`numpy:numpy.ndarray`
         Note that the range dimension must be the last dimension of the
         input array.
-
-    N : integer (must be either 3 or 5, 3 by default)
+    ndespeckle : int
+        (must be either 3 or 5, 3 by default),
         Width of the window in which we check for speckle
-
-    copy : Boolean
+    copy : bool
         If True, the input array will remain unchanged.
 
     """
-    assert N in (3, 5), \
-        "Window size N for function linear_despeckle must be 3 or 5."
+    assert ndespeckle in (3, 5), \
+        "Window size ndespeckle for function linear_despeckle must be 3 or 5."
     if copy:
         data = data.copy()
     axis = data.ndim - 1
@@ -714,7 +489,7 @@ def linear_despeckle(data, N=3, copy=False):
     arr[np.isnan(data)] = 0
     arr_plus1 = np.roll(arr, shift=1, axis=axis)
     arr_minus1 = np.roll(arr, shift=-1, axis=axis)
-    if N == 3:
+    if ndespeckle == 3:
         # for a window of size 3
         test = arr + arr_plus1 + arr_minus1
         data[np.logical_and(np.logical_not(np.isnan(data)), test < 2)] = np.nan
@@ -731,19 +506,22 @@ def linear_despeckle(data, N=3, copy=False):
 
 
 def texture(data):
-    """
+    """Compute the texture of data.
+
     Compute the texture of the data by comparing values with a 3x3 neighborhood
-    (based on :cite:`Gourley2007`).
-    NaN values in the original array have NaN textures.
+    (based on :cite:`Gourley2007`). NaN values in the original array have
+    NaN textures.
 
     Parameters
     ----------
-    data : multi-dimensional array with shape (..., number of beams, number
+    data : :class:`numpy:numpy.ndarray`
+        multi-dimensional array with shape (..., number of beams, number
         of range bins)
 
     Returns
     ------
-    texture : array of textures with the same shape as data
+    texture : :class:`numpy:numpy.ndarray`
+        array of textures with the same shape as data
 
     """
     x1 = np.roll(data, 1, -2)  # center:2
@@ -779,73 +557,5 @@ def texture(data):
     return np.sqrt(num / xa_valid_count)
 
 
-def contiguous_regions(condition):
-    """Finds contiguous True regions of the boolean array "condition".
-
-    This function was adopted from an StackOverflow answer as proposed
-    by Joe Kington in 2010 :cite:`Consecutive-values`.
-
-    Parameters
-    ----------
-    condition : 1d boolean array
-
-    Returns
-    -------
-    output : a 2D array where the first column is the start index of the region
-        and the second column is the end index.
-    """
-
-    # Find the indices of changes in "condition"
-    d = np.diff(condition)
-    idx, = d.nonzero()
-
-    # We need to start things after the change in "condition". Therefore,
-    # we'll shift the index by 1 to the right.
-    idx += 1
-
-    if condition[0]:
-        # If the start of condition is True prepend a 0
-        idx = np.r_[0, idx]
-
-    if condition[-1]:
-        # If the end of condition is True, append the length of the array
-        idx = np.r_[idx, condition.size]  # Edit
-
-    # Reshape the result into two columns
-    idx.shape = (-1, 2)
-    return idx
-
-
-# TO UTILS
-def medfilt_along_axis(x, N, axis=-1):
-    """Applies median filter smoothing on one axis of an N-dimensional array.
-    """
-    kernel_size = np.array(x.shape)
-    kernel_size[:] = 1
-    kernel_size[axis] = N
-    return medfilt(x, kernel_size)
-
-
-# TO UTILS
-def gradient_along_axis(x):
-    """Computes gradient along last axis of an N-dimensional array
-    """
-    axis = -1
-    newshape = np.array(x.shape)
-    newshape[axis] = 1
-    diff_begin = (x[..., 1] - x[..., 0]).reshape(newshape)
-    diff_end = (x[..., -1] - x[..., -2]).reshape(newshape)
-    diffs = ((x - np.roll(x, 2, axis)) / 2.)
-    diffs = np.append(diffs[..., 2:], diff_end, axis=axis)
-    return np.insert(diffs, 0, diff_begin, axis=axis)
-
-
-# TO UTILS
-def gradient_from_smoothed(x, N=5):
-    """Computes gradient of smoothed data along final axis of an array
-    """
-    return gradient_along_axis(medfilt_along_axis(x, N)).astype("f4")
-
-
 if __name__ == '__main__':
     print('wradlib: Calling module <dp> as main...')
