@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: UTF-8 -*-
-# Copyright (c) 2011-2017, wradlib developers.
+# Copyright (c) 2011-2018, wradlib developers.
 # Distributed under the MIT License. See LICENSE.txt for more info.
 
 """
@@ -26,8 +26,6 @@ def get_radolan_coords(lon, lat, trig=False):
     """
     Calculates x,y coordinates of radolan grid from lon, lat
 
-    .. versionadded:: 0.4.0
-
     Parameters
     ----------
 
@@ -72,8 +70,6 @@ def get_radolan_coords(lon, lat, trig=False):
 def get_radolan_grid(nrows=None, ncols=None, trig=False, wgs84=False):
     """Calculates x/y coordinates of radolan grid of the German Weather Service
 
-    .. versionadded:: 0.4.0
-
     Returns the x,y coordinates of the radolan grid positions
     (lower left corner of every pixel). The radolan grid is a
     polarstereographic projection, the projection information was taken from
@@ -162,7 +158,8 @@ def get_radolan_grid(nrows=None, ncols=None, trig=False, wgs84=False):
     >>> print("{0}, ({1:.4f}, {2:.4f})".format(radolan_grid.shape, *radolan_grid[0,0,:]))  # noqa
     (900, 900, 2), (3.5889, 46.9526)
 
-    See :ref:`notebooks/radolan/radolan_grid.ipynb#Polar-Stereographic-Projection`.  # noqa
+    See :ref:`/notebooks/radolan/radolan_grid.ipynb#\
+Polar-Stereographic-Projection`.
 
     Raises
     ------
@@ -239,8 +236,6 @@ def xyz_to_spherical(xyz, alt=0, proj=None, ke=4. / 3.):
     coordinates (x, y, z) with respect to the reference altitude (asl)
     considering earth's geometry (proj).
 
-    .. versionadded:: 0.11.2
-
     Parameters
     ----------
     xyz : :class:`numpy:numpy.ndarray`
