@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: UTF-8 -*-
-# Copyright (c) 2011-2017, wradlib developers.
+# Copyright (c) 2011-2018, wradlib developers.
 # Distributed under the MIT License. See LICENSE.txt for more info.
 
 """
@@ -11,10 +11,9 @@ Vector Functions (GDAL)
    :nosignatures:
    :toctree: generated/
 
-   get_shape_coordinates
-   get_shape_points
+   get_vector_coordinates
+   get_vector_points
    transform_geometry
-   get_shape_coordinates
    ogr_create_layer
    ogr_copy_layer
    ogr_copy_layer_by_name
@@ -28,18 +27,17 @@ Vector Functions (GDAL)
 
 import numpy as np
 from osgeo import gdal, ogr
+from .projection import get_default_projection
+import warnings
 ogr.UseExceptions()
 gdal.UseExceptions()
 
 
-def get_shape_points(geom):
-    """
-    Extract coordinate points from given ogr geometry as generator object
+def get_vector_points(geom):
+    """Extract coordinate points from given ogr geometry as generator object
 
     If geometries are nested, function recurses.
 
-    .. versionadded:: 0.6.0
-
     Parameters
     ----------
     geom : ogr.Geometry
@@ -50,66 +48,77 @@ def get_shape_points(geom):
         expands to Nx2 dimensional nested point arrays
     """
 
-    type = geom.GetGeometryType()
-    if type:
+    geomtype = geom.GetGeometryType()
+    if geomtype > 1:
         # 1D Geometries, LINESTRINGS
-        if type == 2:
+        if geomtype == 2:
             result = np.array(geom.GetPoints())
             yield result
         # RINGS, POLYGONS, MULTIPOLYGONS, MULTILINESTRINGS
-        elif type > 2:
+        elif geomtype > 2:
             # iterate over geometries and recurse
             for item in geom:
-                for result in get_shape_points(item):
+                for result in get_vector_points(item):
                     yield result
     else:
-        print("Unknown Geometry")
+        warnings.warn("unsupported geometry type detected in "
+                      "wradlib.georef.get_vector_points - skipping")
 
 
-def transform_geometry(geom, dest_srs):
-    """
-    Perform geotransformation to given destination SpatialReferenceSystem
+def transform_geometry(geom, dest_srs, **kwargs):
+    """Perform geotransformation to given destination SpatialReferenceSystem
 
     It transforms coordinates to a given destination osr spatial reference
     if a geotransform is neccessary.
 
-    .. versionadded:: 0.6.0
-
     Parameters
     ----------
     geom : ogr.geometry
-    dest_srs: osr.SpatialReference
+    dest_srs : osr.SpatialReference
         Destination Projection
 
+    Keyword Arguments
+    -----------------
+    source_srs : osr.SpatialReference
+        Source Projection
+
     Returns
     -------
     geom : ogr.Geometry
         Transformed Geometry
     """
+    gsrs = geom.GetSpatialReference()
+    srs = kwargs.get('source_srs', gsrs)
+
+    # srs is None assume wgs84 lonlat, but warn too
+    if srs is None:
+        srs = get_default_projection()
+        warnings.warn("geometry without spatial reference - assuming wgs84")
 
     # transform if not the same spatial reference system
-    if not geom.GetSpatialReference().IsSame(dest_srs):
+    if not srs.IsSame(dest_srs):
+        if gsrs is None:
+            geom.AssignSpatialReference(srs)
         geom.TransformTo(dest_srs)
 
     return geom
 
 
-def get_shape_coordinates(layer, **kwargs):
-    """
-    Function iterates over gdal ogr layer features and packs extracted shape
-    coordinate points into nested ndarray
+def get_vector_coordinates(layer, **kwargs):
+    """Function iterates over gdal ogr layer features and packs extracted \
+    vector coordinate points into nested ndarray
 
     It transforms coordinates to a given destination osr spatial reference if
     dest_srs is given and a geotransform is neccessary.
 
-    .. versionadded:: 0.6.0
-
     Parameters
     ----------
     layer : ogr.Layer
 
-    Keywords
-    --------
+    Keyword Arguments
+    -----------------
+    source_srs : osr.SpatialReference
+        Source Projection
     dest_srs: osr.SpatialReference
         Destination Projection
     key : string
@@ -126,6 +135,7 @@ def get_shape_coordinates(layer, **kwargs):
 
     shp = []
 
+    source_srs = kwargs.get('source_srs', None)
     dest_srs = kwargs.get('dest_srs', None)
     key = kwargs.get('key', None)
     if key:
@@ -140,9 +150,9 @@ def get_shape_coordinates(layer, **kwargs):
                 attrs.append(feature[key])
             geom = feature.GetGeometryRef()
             if dest_srs:
-                transform_geometry(geom, dest_srs)
+                transform_geometry(geom, dest_srs, source_srs=source_srs)
             # get list of xy-coordinates
-            reslist = list(get_shape_points(geom))
+            reslist = list(get_vector_points(geom))
             shp.append(np.squeeze(np.array(reslist)))
 
     shp = np.squeeze(np.array(shp))
@@ -153,8 +163,6 @@ def get_shape_coordinates(layer, **kwargs):
 def ogr_create_layer(ds, name, srs=None, geom_type=None, fields=None):
     """Creates OGR.Layer objects in gdal.Dataset object.
 
-    .. versionadded:: 0.7.0
-
     Creates one OGR.Layer with given name in given gdal.Dataset object
     using given OGR.GeometryType and FieldDefinitions
 
@@ -190,8 +198,6 @@ def ogr_create_layer(ds, name, srs=None, geom_type=None, fields=None):
 def ogr_copy_layer(src_ds, index, dst_ds, reset=True):
     """ Copy OGR.Layer object.
 
-    .. versionadded:: 0.7.0
-
     Copy OGR.Layer object from src_ds gdal.Dataset to dst_ds gdal.Dataset
 
     Parameters
@@ -218,8 +224,6 @@ def ogr_copy_layer(src_ds, index, dst_ds, reset=True):
 def ogr_copy_layer_by_name(src_ds, name, dst_ds, reset=True):
     """ Copy OGR.Layer object.
 
-    .. versionadded:: 0.8.0
-
     Copy OGR.Layer object from src_ds gdal.Dataset to dst_ds gdal.Dataset
 
     Parameters
@@ -236,6 +240,8 @@ def ogr_copy_layer_by_name(src_ds, name, dst_ds, reset=True):
     # get and copy src geometry layer
 
     src_lyr = src_ds.GetLayerByName(name)
+    if src_lyr is None:
+        raise ValueError("OGR layer 'name' not found in dataset")
     if reset:
         src_lyr.ResetReading()
         src_lyr.SetSpatialFilter(None)
@@ -246,8 +252,6 @@ def ogr_copy_layer_by_name(src_ds, name, dst_ds, reset=True):
 def ogr_add_feature(ds, src, name=None):
     """ Creates OGR.Feature objects in OGR.Layer object.
 
-    .. versionadded:: 0.7.0
-
     OGR.Features are built from numpy src points or polygons.
 
     OGR.Features 'FID' and 'index' corresponds to source data element
@@ -286,8 +290,6 @@ def ogr_add_feature(ds, src, name=None):
 def ogr_add_geometry(layer, geom, attrs):
     """ Copies single OGR.Geometry object to an OGR.Layer object.
 
-    .. versionadded:: 0.7.0
-
     Given OGR.Geometry is copied to new OGR.Feature and
     written to given OGR.Layer by given index. Attributes are attached.
 
@@ -313,8 +315,6 @@ def ogr_add_geometry(layer, geom, attrs):
 def numpy_to_ogr(vert, geom_name):
     """Convert a vertex array to gdal/ogr geometry.
 
-    .. versionadded:: 0.7.0
-
     Using JSON as a vehicle to efficiently deal with numpy arrays.
 
     Parameters
@@ -343,8 +343,6 @@ def numpy_to_ogr(vert, geom_name):
 def ogr_to_numpy(ogrobj):
     """Backconvert a gdal/ogr geometry to a numpy vertex array.
 
-    .. versionadded:: 0.7.0
-
     Using JSON as a vehicle to efficiently deal with numpy arrays.
 
     Parameters
@@ -366,8 +364,6 @@ def ogr_to_numpy(ogrobj):
 def ogr_geocol_to_numpy(ogrobj):
     """Backconvert a gdal/ogr geometry Collection to a numpy vertex array.
 
-    .. versionadded:: 0.7.0
-
     This extracts only Polygon geometries!
 
     Using JSON as a vehicle to efficiently deal with numpy arrays.
@@ -384,9 +380,9 @@ def ogr_geocol_to_numpy(ogrobj):
 
     """
     jsonobj = eval(ogrobj.ExportToJson())
-
     mpol = []
     for item in jsonobj['geometries']:
+        print(item['type'])
         if item['type'] == 'Polygon':
             mpol.append(item['coordinates'])
 
