@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-# Copyright (c) 2011-2017, wradlib developers.
+# Copyright (c) 2011-2018, wradlib developers.
 # Distributed under the MIT License. See LICENSE.txt for more info.
 
 """
@@ -10,8 +10,8 @@ HDF Data I/O
    :toctree: generated/
 
    read_generic_hdf5
-   read_OPERA_hdf5
-   read_GAMIC_hdf5
+   read_opera_hdf5
+   read_gamic_hdf5
    to_hdf5
    from_hdf5
    read_gpm
@@ -31,12 +31,6 @@ import datetime as dt
 from ..zonalstats import get_clip_mask
 
 
-def browse_hdf5_group(grp):
-    """Browses one hdf5 file level
-    """
-    pass
-
-
 def read_generic_hdf5(fname):
     """Reads hdf5 files according to their structure
 
@@ -59,7 +53,7 @@ def read_generic_hdf5(fname):
 
     Examples
     --------
-    See :ref:`notebooks/fileio/wradlib_radar_formats.ipynb#Generic-HDF5`.
+    See :ref:`/notebooks/fileio/wradlib_radar_formats.ipynb#Generic-HDF5`.
     """
     f = h5py.File(fname, "r")
     fcontent = {}
@@ -84,7 +78,7 @@ def read_generic_hdf5(fname):
     return fcontent
 
 
-def read_OPERA_hdf5(fname):
+def read_opera_hdf5(fname):
     """Reads hdf5 files according to OPERA conventions
 
     Please refer to the OPERA data model documentation :cite:`OPERA-data-model`
@@ -137,8 +131,6 @@ def read_OPERA_hdf5(fname):
 def read_gamic_scan_attributes(scan, scan_type):
     """Read attributes from one particular scan from a GAMIC hdf5 file
 
-    Provided by courtesy of Kai Muehlbauer (University of Bonn).
-
     Parameters
     ----------
     scan : object
@@ -220,8 +212,6 @@ def read_gamic_scan_attributes(scan, scan_type):
 def read_gamic_scan(scan, scan_type, wanted_moments):
     """Read data from one particular scan from GAMIC hdf5 file
 
-    Provided by courtesy of Kai Muehlbauer (University of Bonn).
-
     Parameters
     ----------
     scan : object
@@ -282,12 +272,11 @@ def read_gamic_scan(scan, scan_type, wanted_moments):
     return data, sattrs
 
 
-def read_GAMIC_hdf5(filename, wanted_elevations=None, wanted_moments=None):
-    """Data reader for hdf5 files produced by the commercial
+def read_gamic_hdf5(filename, wanted_elevations=None, wanted_moments=None):
+    """Data reader for hdf5 files produced by the commercial \
     GAMIC Enigma V3 MURAN software
 
-    Provided by courtesy of Kai Muehlbauer (University of Bonn). See GAMIC
-    homepage for further info (http://www.gamic.com).
+    See GAMIC homepage for further info (https://www.gamic.com).
 
     Parameters
     ----------
@@ -307,7 +296,7 @@ def read_GAMIC_hdf5(filename, wanted_elevations=None, wanted_moments=None):
 
     Examples
     --------
-    See :ref:`notebooks/fileio/wradlib_radar_formats.ipynb#GAMIC-HDF5`.
+    See :ref:`/notebooks/fileio/wradlib_radar_formats.ipynb#GAMIC-HDF5`.
     """
 
     # check elevations
@@ -447,18 +436,42 @@ def from_hdf5(fpath, dataset="data"):
     return data, metadata
 
 
-def read_gpm(filename, bbox):
+def read_gpm(filename, bbox=None):
+    """Reads GPM files for matching with GR
+
+    Parameters
+    ----------
+    filename : string
+        path of the GPM file
+    bbox : dict
+        dictionary with bounding box coordinates (lon, lat),
+        defaults to None
+
+    Returns
+    -------
+    gpm_data : dict
+        dictionary of gpm data
+
+    Examples
+    --------
+    See :ref:`/notebooks/match3d/wradlib_match_workflow.ipynb`.
+    """
     pr_data = Dataset(filename, mode="r")
     lon = pr_data['NS'].variables['Longitude']
     lat = pr_data['NS'].variables['Latitude']
 
-    poly = [[bbox['left'], bbox['bottom']],
-            [bbox['left'], bbox['top']],
-            [bbox['right'], bbox['top']],
-            [bbox['right'], bbox['bottom']],
-            [bbox['left'], bbox['bottom']]]
-    mask = get_clip_mask(np.dstack((lon[:], lat[:])), poly)
+    if bbox is not None:
+        poly = [[bbox['left'], bbox['bottom']],
+                [bbox['left'], bbox['top']],
+                [bbox['right'], bbox['top']],
+                [bbox['right'], bbox['bottom']],
+                [bbox['left'], bbox['bottom']]]
+        mask = get_clip_mask(np.dstack((lon[:], lat[:])), poly)
+    else:
+        mask = np.ones_like(lon, dtype=bool)
+
     mask = np.nonzero(np.count_nonzero(mask, axis=1))
+
     lon = lon[mask]
     lat = lat[mask]
 
@@ -549,7 +562,28 @@ def read_gpm(filename, bbox):
     return gpm_data
 
 
-def read_trmm(filename1, filename2, bbox):
+def read_trmm(filename1, filename2, bbox=None):
+    """Reads TRMM files for matching with GR
+
+    Parameters
+    ----------
+    filename1 : string
+        path of the TRMM 2A23 file
+    filename2 : string
+        path of the TRMM 2A25 file
+    bbox : dict
+        dictionary with bounding box coordinates (lon, lat),
+        defaults to None
+
+    Returns
+    -------
+    trmm_data : dict
+        dictionary of trmm data
+
+    Examples
+    --------
+    See :ref:`/notebooks/match3d/wradlib_match_workflow.ipynb`.
+    """
     # trmm 2A23 and 2A25 data is hdf4
     pr_data1 = Dataset(filename1, mode="r")
     pr_data2 = Dataset(filename2, mode="r")
@@ -557,13 +591,18 @@ def read_trmm(filename1, filename2, bbox):
     lon = pr_data1.variables['Longitude']
     lat = pr_data1.variables['Latitude']
 
-    poly = [[bbox['left'], bbox['bottom']],
-            [bbox['left'], bbox['top']],
-            [bbox['right'], bbox['top']],
-            [bbox['right'], bbox['bottom']],
-            [bbox['left'], bbox['bottom']]]
-    mask = get_clip_mask(np.dstack((lon[:], lat[:])), poly)
+    if bbox is not None:
+        poly = [[bbox['left'], bbox['bottom']],
+                [bbox['left'], bbox['top']],
+                [bbox['right'], bbox['top']],
+                [bbox['right'], bbox['bottom']],
+                [bbox['left'], bbox['bottom']]]
+        mask = get_clip_mask(np.dstack((lon[:], lat[:])), poly)
+    else:
+        mask = np.ones_like(lon, dtype=bool)
+
     mask = np.nonzero(np.count_nonzero(mask, axis=1))
+
     lon = pr_data1.variables['Longitude'][mask]
     lat = pr_data1.variables['Latitude'][mask]
 
