@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-# Copyright (c) 2016, wradlib developers.
+# Copyright (c) 2011-2018, wradlib developers.
 # Distributed under the MIT License. See LICENSE.txt for more info.
 
 """
@@ -27,8 +27,8 @@ This includes for example:
    ExternalDriftKriging
    interpolate
    interpolate_polar
-   cart2irregular_interp
-   cart2irregular_spline
+   cart_to_irregular_interp
+   cart_to_irregular_spline
 
 """
 
@@ -57,7 +57,7 @@ class MissingTargetsError(Exception):
     pass
 
 
-class IpolBase():
+class IpolBase:
     """
     IpolBase(src, trg)
 
@@ -108,6 +108,8 @@ class IpolBase():
         assert len(vals) == self.numsources, \
             ('Length of value array %d does not correspond to number '
              'of source points %d' % (len(vals), self.numsources))
+        self.valsshape = vals.shape
+        self.valsndim = vals.ndim
 
     def _make_coord_arrays(self, x):
         """
@@ -173,7 +175,7 @@ class Nearest(IpolBase):
 
     Examples
     --------
-    See :ref:`notebooks/interpolation/wradlib_ipol_example.ipynb`.
+    See :ref:`/notebooks/interpolation/wradlib_ipol_example.ipynb`.
 
 
     Note
@@ -200,6 +202,14 @@ class Nearest(IpolBase):
         """
         Evaluate interpolator for values given at the source points.
 
+        You can interpolate multiple datasets of source values (``vals``) at
+        once: the ``vals`` array should have the shape (number of source
+        points, number of source datasets). If you want to interpolate only one
+        set of source values, ``vals`` can have the shape (number of source
+        points, 1) or just (number of source points,) - which is a flat/1-D
+        array. The output will have the same number of dimensions as ``vals``,
+        i.e. it will be a flat 1-D array in case ``vals`` is a 1-D array.
+
         Parameters
         ----------
         vals : ndarray of float, shape (numsourcepoints, ...)
@@ -238,7 +248,7 @@ class Idw(IpolBase):
 
     Examples
     --------
-    See :ref:`notebooks/interpolation/wradlib_ipol_example.ipynb`.
+    See :ref:`/notebooks/interpolation/wradlib_ipol_example.ipynb`.
 
     Note
     ----
@@ -279,6 +289,14 @@ class Idw(IpolBase):
         """
         Evaluate interpolator for values given at the source points.
 
+        You can interpolate multiple datasets of source values (``vals``) at
+        once: the ``vals`` array should have the shape (number of source
+        points, number of source datasets). If you want to interpolate only one
+        set of source values, ``vals`` can have the shape (number of source
+        points, 1) or just (number of source points,) - which is a flat/1-D
+        array. The output will have the same number of dimensions as ``vals``,
+        i.e. it will be a flat 1-D array in case ``vals`` is a 1-D array.
+
         Parameters
         ----------
         vals : ndarray of float, shape (numsourcepoints, ...)
@@ -298,7 +316,7 @@ class Idw(IpolBase):
         self._check_shape(vals)
         outshape = list(vals.shape)
         outshape[0] = len(self.dists)
-        interpol = (np.repeat(np.nan, util._shape2size(outshape)).
+        interpol = (np.repeat(np.nan, util._shape_to_size(outshape)).
                     reshape(tuple(outshape)).astype('f4'))
         # weights is the container for the weights (a list)
         weights = list(range(len(self.dists)))
@@ -347,7 +365,7 @@ class Linear(IpolBase):
 
     Examples
     --------
-    See :ref:`notebooks/interpolation/wradlib_ipol_example.ipynb`.
+    See :ref:`/notebooks/interpolation/wradlib_ipol_example.ipynb`.
     """
 
     def __init__(self, src, trg):
@@ -365,6 +383,14 @@ class Linear(IpolBase):
         """
         Evaluate interpolator for values given at the source points.
 
+        You can interpolate multiple datasets of source values (``vals``) at
+        once: the ``vals`` array should have the shape (number of source
+        points, number of source datasets). If you want to interpolate only one
+        set of source values, ``vals`` can have the shape (number of source
+        points, 1) or just (number of source points,) - which is a flat/1-D
+        array. The output will have the same number of dimensions as ``vals``,
+        i.e. it will be a flat 1-D array in case ``vals`` is a 1-D array.
+
         Parameters
         ----------
         vals : ndarray of float, shape (numsourcepoints, ...)
@@ -387,15 +413,16 @@ class Linear(IpolBase):
 # -----------------------------------------------------------------------------
 def parse_covariogram(cov_model):
     """"""
-    patterns = [re.compile('([\d\.]+) Nug\(([\d\.]+)\)'),  # nugget
-                re.compile('([\d\.]+) Lin\(([\d\.]+)\)'),  # linear
-                re.compile('([\d\.]+) Sph\(([\d\.]+)\)'),  # spherical
-                re.compile('([\d\.]+) Exp\(([\d\.]+)\)'),  # exponential
-                re.compile('([\d\.]+) Gau\(([\d\.]+)\)'),  # gaussian
-                re.compile('([\d\.]+) Mat\(([\d\.]+)\)\^([\d\.]+)'),  # matern
-                re.compile('([\d\.]+) Pow\(([\d\.]+)\)'),  # power
+    patterns = [re.compile(r'([\d\.]+) Nug\(([\d\.]+)\)'),  # nugget
+                re.compile(r'([\d\.]+) Lin\(([\d\.]+)\)'),  # linear
+                re.compile(r'([\d\.]+) Sph\(([\d\.]+)\)'),  # spherical
+                re.compile(r'([\d\.]+) Exp\(([\d\.]+)\)'),  # exponential
+                re.compile(r'([\d\.]+) Gau\(([\d\.]+)\)'),  # gaussian
+                re.compile(r'([\d\.]+) Mat\(([\d\.]+)\)\^([\d\.]+)'),  # matern
+                re.compile(r'([\d\.]+) Pow\(([\d\.]+)\)'),  # power
                 # cauchy
-                re.compile('([\d\.]+) Cau\(([\d\.]+)\)\^([\d\.]+)\^([\d\.]+)'),
+                re.compile(r'([\d\.]+) '
+                           r'Cau\(([\d\.]+)\)\^([\d\.]+)\^([\d\.]+)'),
                 ]
 
     cov_funs = [cov_nug,
@@ -431,8 +458,8 @@ def _make_cov(func, params):
 
 
 def cov_nug(h, sill, rng):
-    """nugget covariance function
-    :math:`\\gamma(h) = s ` for :math:`h \\leq r`, 0 otherwise
+    r"""nugget covariance function
+    :math:`\gamma(h) = s ` for :math:`h \leq r`, 0 otherwise
     Therefore, usually rng is set to 0
     """
     h = np.asanyarray(h)
@@ -478,15 +505,15 @@ def cov_mat(h, sill=1.0, rng=1.0, shp=0.5):
         c = cov_gau(h, sill, rng)
     else:
         # modified bessel function of second kind of order v
-        Kv = scipy.special.kv
+        kv = scipy.special.kv
         # Gamma function
-        Tau = scipy.special.gamma
+        tau = scipy.special.gamma
 
         fac1 = h / rng * 2.0 * np.sqrt(shp)
-        fac2 = (Tau(shp) * 2.0 ** (shp - 1.0))
+        fac2 = (tau(shp) * 2.0 ** (shp - 1.0))
 
         c = np.where(h != 0, sill * 1.0 /
-                     fac2 * fac1 ** shp * Kv(shp, fac1), sill)
+                     fac2 * fac1 ** shp * kv(shp, fac1), sill)
 
     return c
 
@@ -509,10 +536,11 @@ def cov_cau(h, sill=1., rng=1., alpha=1., beta=1.0):
 
 
 class OrdinaryKriging(IpolBase):
-    """Interpolate using Ordinary Kriging.
-
+    r"""
     OrdinaryKriging(src, trg, cov='1.0 Exp(10000.)', nnearest=12)
 
+    Interpolate using Ordinary Kriging
+
     (Co-)Variogram definitions are given in the syntax that ``gstat`` uses.
     It allows nesting of different basic variogram types using linear
     combinations.
@@ -565,7 +593,7 @@ class OrdinaryKriging(IpolBase):
 
     Examples
     --------
-    See :ref:`notebooks/interpolation/wradlib_ipol_example.ipynb`.
+    See :ref:`/notebooks/interpolation/wradlib_ipol_example.ipynb`.
     """
 
     def __init__(self, src, trg, cov='1.0 Exp(10000.)', nnearest=12):
@@ -641,6 +669,14 @@ class OrdinaryKriging(IpolBase):
         """
         Evaluate interpolator for values given at the source points.
 
+        You can interpolate multiple datasets of source values (``vals``) at
+        once: the ``vals`` array should have the shape (number of source
+        points, number of source datasets). If you want to interpolate only one
+        set of source values, ``vals`` can have the shape (number of source
+        points, 1) or just (number of source points,) - which is a flat/1-D
+        array. The output will have the same number of dimensions as ``vals``,
+        i.e. it will be a flat 1-D array in case ``vals`` is a 1-D array.
+
         Parameters
         ----------
         vals : ndarray of float, shape (numsourcepoints, numfields)
@@ -662,7 +698,10 @@ class OrdinaryKriging(IpolBase):
         ip = np.add.reduce(weights[:, :-1, np.newaxis] * v[self.ix, ...],
                            axis=1)
 
-        return ip
+        if vals.ndim == 1:
+            return ip.ravel()
+        else:
+            return ip
 
 
 class ExternalDriftKriging(IpolBase):
@@ -704,6 +743,9 @@ class ExternalDriftKriging(IpolBase):
     If any of them is given on initialization its values may be overridden
     by passing new values to the __call__ method.
 
+    Examples
+    --------
+    See :ref:`/notebooks/interpolation/wradlib_ipol_example.ipynb`.
     """
 
     def __init__(self, src, trg, cov='1.0 Exp(10000.)', nnearest=12,
@@ -796,6 +838,14 @@ class ExternalDriftKriging(IpolBase):
         """
         Evaluate interpolator for values given at the source points.
 
+        You can interpolate multiple datasets of source values (``vals``) at
+        once: the ``vals`` array should have the shape (number of source
+        points, number of source datasets). If you want to interpolate only one
+        set of source values, ``vals`` can have the shape (number of source
+        points, 1) or just (number of source points,) - which is a flat/1-D
+        array. The output will have the same number of dimensions as ``vals``,
+        i.e. it will be a flat 1-D array in case ``vals`` is a 1-D array.
+
         Parameters
         ----------
         vals : ndarray of float, shape (numsourcepoints, numfields)
@@ -863,13 +913,16 @@ class ExternalDriftKriging(IpolBase):
                 self.weights.append(weights)
                 self.estimation_variance.append(variances)
 
-        return ip
+        if vals.ndim == 1:
+            return ip.ravel()
+        else:
+            return ip
 
 
 # -----------------------------------------------------------------------------
 # Wrapper functions
 # -----------------------------------------------------------------------------
-def interpolate(src, trg, vals, Interpolator, *args, **kwargs):
+def interpolate(src, trg, vals, ipclass, *args, **kwargs):
     """
     Convenience function to use the interpolation classes in an efficient way
 
@@ -907,15 +960,15 @@ def interpolate(src, trg, vals, Interpolator, *args, **kwargs):
         Data point coordinates of the target points.
     vals : ndarray of float, shape (numsourcepoints, ...)
         Values at the source points which to interpolate
-    Interpolator : a class which inherits from IpolBase
+    ipclass : a class which inherits from IpolBase
 
     Other Parameters
     ----------------
-    *args : arguments of Interpolator (see class documentation)
+    *args : arguments of ipclass (see class documentation)
 
     Keyword Arguments
     -----------------
-    **kwargs : keyword arguments of Interpolator (see class documentation)
+    **kwargs : keyword arguments of ipclass (see class documentation)
 
     Examples
     --------
@@ -936,11 +989,11 @@ def interpolate(src, trg, vals, Interpolator, *args, **kwargs):
         # source values are one dimensional, we have just
         # to remove invalid data
         ix_valid = np.where(np.isfinite(vals))[0]
-        ip = Interpolator(src[ix_valid], trg, *args, **kwargs)
+        ip = ipclass(src[ix_valid], trg, *args, **kwargs)
         result = ip(vals[ix_valid])
     elif vals.ndim == 2:
         # this implementation for 2 dimensions needs generalization
-        ip = Interpolator(src, trg, *args, **kwargs)
+        ip = ipclass(src, trg, *args, **kwargs)
         result = ip(vals)
         nan_in_result = np.where(np.isnan(result))
         # nan_in_vals = np.where(np.isnan(vals))
@@ -948,26 +1001,26 @@ def interpolate(src, trg, vals, Interpolator, *args, **kwargs):
             ix_good = np.where(np.isfinite(vals[..., i]))[0]
             ix_broken_targets = (nan_in_result[0]
                                  [np.where(nan_in_result[-1] == i)[0]])
-            ip = Interpolator(src[ix_good],
-                              trg[nan_in_result[0]
-                              [np.where(nan_in_result[-1] == i)[0]]],
-                              *args, **kwargs)
+            ip = ipclass(src[ix_good],
+                         trg[nan_in_result[0]
+                         [np.where(nan_in_result[-1] == i)[0]]],
+                         *args, **kwargs)
             tmp = ip(vals[ix_good, i].reshape((len(ix_good), -1)))
             result[ix_broken_targets, i] = tmp.ravel()
     else:
-        if not np.any(np.isnan(vals.ravel())):
-            raise Exception(
-                'At the moment, <interpolate> can only deal with NaN values '
-                'in <vals> if vals has less than 3 dimension.')
+        if np.any(np.isnan(vals.ravel())):
+            raise NotImplementedError('WRADLIB: At the moment, <interpolate> '
+                                      'can only deal with NaN values in <vals>'
+                                      ' if <vals> has less than 3 dimension.')
         else:
             # if no NaN value are in <vals> we can safely apply the
-            # Interpolator as is
-            ip = Interpolator(src, trg, *args, **kwargs)
-            result = ip(vals[ix_valid])
+            # ipclass as is
+            ip = ipclass(src, trg, *args, **kwargs)
+            result = ip(vals)
     return result
 
 
-def interpolate_polar(data, mask=None, Interpolator=Nearest):
+def interpolate_polar(data, mask=None, ipclass=Nearest):
     """
     Convenience function to interpolate polar data
 
@@ -981,7 +1034,7 @@ def interpolate_polar(data, mask=None, Interpolator=Nearest):
         boolean array with pixels to be interpolated set to True;
 
         must have the same shape as data
-    Interpolator : a class which inherits from IpolBase
+    ipclass : a class which inherits from IpolBase
 
     Returns
     -------
@@ -996,11 +1049,11 @@ def interpolate_polar(data, mask=None, Interpolator=Nearest):
     >>> data = np.arange(12.).reshape(4,3)
     >>> masked_values = (data==2) | (data==9)
     >>> # interpolate the masked data based on ''masked_values''
-    >>> filled_a = wrl.ipol.interpolate_polar(data, mask = masked_values, Interpolator = wrl.ipol.Linear)  # noqa
+    >>> filled_a = wrl.ipol.interpolate_polar(data, mask = masked_values, ipclass = wrl.ipol.Linear)  # noqa
     >>> ax, pm = wrl.vis.plot_ppi(filled_a)
     >>> # the same result can be achieved by using an masked array instead of an explicit mask  # noqa
     >>> mdata = np.ma.array(data, mask = masked_values)
-    >>> filled_b = wrl.ipol.interpolate_polar(mdata, Interpolator = wrl.ipol.Linear)  # noqa
+    >>> filled_b = wrl.ipol.interpolate_polar(mdata, ipclass = wrl.ipol.Linear)  # noqa
     >>> ax, pm = wrl.vis.plot_ppi(filled_b)
 
 
@@ -1033,7 +1086,7 @@ def interpolate_polar(data, mask=None, Interpolator=Nearest):
     values_list = np.delete(data, clutter_indices)
     filled_data = data.copy().ravel()
     # interpolate masked bins
-    filling = interpolate(src_coord, trg_coord, values_list, Interpolator)
+    filling = interpolate(src_coord, trg_coord, values_list, ipclass)
     # fill data with the interpolations
     filled_data[clutter_indices] = filling.astype(filled_data.dtype)
     # in case of nans as processed at the rim when interpolating linear,
@@ -1043,19 +1096,17 @@ def interpolate_polar(data, mask=None, Interpolator=Nearest):
                               biny[np.where(np.isnan(filled_data))]])
                      .transpose())
         filling = interpolate(src_coord, trg_coord, values_list,
-                              Interpolator=Nearest)
+                              ipclass=Nearest)
         filled_data[np.where(np.isnan(filled_data))] = filling
     return filled_data.reshape(data.shape[0], data.shape[1])
 
 
-def cart2irregular_interp(cartgrid, values, newgrid, **kwargs):
+def cart_to_irregular_interp(cartgrid, values, newgrid, **kwargs):
     """
     Interpolate array ``values`` defined by cartesian coordinate array
     ``cartgrid`` to new coordinates defined by ``newgrid`` using
     nearest neighbour, linear or cubic interpolation
 
-    .. versionadded:: 0.6.0
-
     Slow for large arrays
 
     Keyword arguments are fed to :func:`scipy:scipy.interpolate.griddata`
@@ -1092,16 +1143,11 @@ def cart2irregular_interp(cartgrid, values, newgrid, **kwargs):
     return interp
 
 
-def cart2irregular_spline(cartgrid, values, newgrid, **kwargs):
+def cart_to_irregular_spline(cartgrid, values, newgrid, **kwargs):
     """
     Map array ``values`` defined by cartesian coordinate array ``cartgrid``
     to new coordinates defined by ``newgrid`` using spline interpolation.
 
-    .. versionadded:: 0.6.0
-
-    .. versionchanged:: 0.10.0
-       Accept data/coords with origin 'lower' or 'upper'.
-
     Keyword arguments are fed through to
     :func:`scipy:scipy.ndimage.map_coordinates`
 
@@ -1122,8 +1168,8 @@ def cart2irregular_spline(cartgrid, values, newgrid, **kwargs):
 
     Examples
     --------
-    See :ref:`notebooks/beamblockage/wradlib_beamblock.ipynb#\
-Read-DEM-Raster-Data`.
+    See :ref:`/notebooks/beamblockage/wradlib_beamblock.ipynb#\
+Preprocessing-the-digitial-elevation-model`.
     """
 
     # TODO: dimension checking
