@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-# Copyright (c) 2016, wradlib developers.
+# Copyright (c) 2011-2018, wradlib developers.
 # Distributed under the MIT License. See LICENSE.txt for more info.
 
 """
@@ -18,7 +18,7 @@ account for these effects.
 The first step will normally be to reference the polar volume data in a
 3-dimensional Cartesian coordinate system. The three dimensional Cartesian
 coordinates of the original polar volume data can be computed using
-:meth:`wradlib.vpr.volcoords_from_polar`.
+:func:`wradlib.vpr.volcoords_from_polar`.
 
 Then, we can create regular 3-D grids in order to analyse the vertical profile
 of reflectivity or rainfall intensity. For some applications you might want
@@ -28,8 +28,8 @@ in order to make radar observations at different distances from the radar more
 comparable. Basically, a CAPPI is simply one slice out of a 3-D volume grid.
 Analoguous, we will refer to the elements in a three dimensional Cartesian grid
 as *voxels*. In wradlib, you can create
-CAPPIS (:meth:`wradlib.vpr.CAPPI`) and Pseudo CAPPIs
-(:meth:wradlib.vpr.PseudoCAPPI`) for different altitudes at once.
+CAPPIS (:class:`~wradlib.vpr.CAPPI`) and Pseudo CAPPIs
+(:class:`~wradlib.vpr.PseudoCAPPI`) for different altitudes at once.
 
 Here's an example how a set of CAPPIs can be created from synthetic polar
 volume data::
@@ -64,13 +64,13 @@ volume data::
     # create an instance of the CAPPI class and
     # use it to create a series of CAPPIs
     gridder = wradlib.vpr.CAPPI(polxyz, xyz, maxrange=ranges.max(),
-                                gridshape=gridshape, Ipclass=wradlib.ipol.Idw)
+                                gridshape=gridshape, ipclass=wradlib.ipol.Idw)
     gridded = np.ma.masked_invalid( gridder(poldata) ).reshape(gridshape)
 
     # plot results
     levels = np.linspace(0,100,25)
     wradlib.vis.plot_max_plan_and_vert(x, y, z, gridded, levels=levels,
-                                       cmap=pl.cm.spectral)
+                                       cmap=pl.cm.viridis)
 
 
 .. autosummary::
@@ -78,7 +78,7 @@ volume data::
    :toctree: generated/
 
    volcoords_from_polar
-   make_3D_grid
+   make_3d_grid
    CartesianVolume
    CAPPI
    PseudoCAPPI
@@ -86,40 +86,44 @@ volume data::
 """
 
 import numpy as np
-import scipy
 
 from . import georef as georef
 from . import ipol as ipol
 from . import util as util
-from . import qual as qual
 
 
 class CartesianVolume():
-    """Create 3-D regular volume grid in Cartesian coordinates from polar data
-    with multiple elevation angles
+    """Create 3-D regular volume grid in Cartesian coordinates from polar \
+    data with multiple elevation angles
 
     Parameters
     ----------
-    polcoords : :func:`numpy:numpy.array` of shape (num bins, 3)
-    gridcoords : :func:`numpy:numpy.array` of shape (num voxels, 3)
+    polcoords : :class:`numpy:numpy.ndarray`
+        of shape (num bins, 3)
+    gridcoords : :class:`numpy:numpy.ndarray`
+        of shape (num voxels, 3)
     gridshape : tuple
         shape of the Cartesian grid (num x, num y, num z)
     maxrange : float
         The maximum radar range (must be the same for each elevation angle)
-    Ipclass : an interpolation class from :mod:`wradlib.ipol`
-    ipargs : keyword arguments corresponding to Ipclass
+    ipclass : object
+        an interpolation class from :mod:`wradlib.ipol`
+    ipargs : `**kwargs`
+        keyword arguments corresponding to ``ipclass``
 
     Returns
     -------
-    output : float ndarray of shape (num levels, num x coordinates,
-        num y coordinates)
+    output : :class:`numpy:numpy.ndarray`
+        float 1-d ndarray of the same length as ``gridcoords`` (num voxels,)
 
+    Examples
+    --------
+    See :ref:`/notebooks/workflow/recipe2.ipynb`.
     """
 
     def __init__(self, polcoords, gridcoords, gridshape=None,
                  maxrange=None, minelev=None, maxelev=None,
-                 Ipclass=ipol.Idw, **ipargs):
-        # TODO: rename Ipclas to ipclass
+                 ipclass=ipol.Idw, **ipargs):
         # radar location in Cartesian coordinates
         # TODO: pass projected radar location as argument
         # (allows processing of incomplete polar volumes)
@@ -131,19 +135,21 @@ class CartesianVolume():
                                    maxrange, minelev, maxelev)
         # create an instance of the Interpolation class
         self.trgix = np.where(np.logical_not(self.mask))
-        self.ip = Ipclass(src=polcoords, trg=gridcoords[self.trgix], **ipargs)
+        self.ip = ipclass(src=polcoords, trg=gridcoords[self.trgix], **ipargs)
 
     def __call__(self, data):
         """Interpolates the polar data to 3-dimensional Cartesian coordinates
 
         Parameters
         ----------
-        data : 1-d array of length (num radar bins in volume,)
+        data : :class:`numpy:numpy.ndarray`
+            1-d array of length (num radar bins in volume,)
             The length of this array must be the same as len(polcoords)
 
         Returns
         -------
-        output : 1-d array of length (num voxels,)
+        output : :class:`numpy:numpy.ndarray`
+            1-d array of length (num voxels,)
 
         """
         # Interpolate data in 3-D
@@ -154,22 +160,34 @@ class CartesianVolume():
 
     def _get_mask(self, gridcoords, polcoords=None, gridshape=None,
                   maxrange=None, minelev=None, maxelev=None):
-        """Returns a mask (the base class only contains a dummy function which
-        masks nothing)
+        """Returns a mask
+
+        (the base class only contains a dummy function which masks nothing)
 
         This method needs to be replaced for inherited classes such as CAPPI or
         PseudoCAPPI.
 
         Parameters
         ----------
-        gridcoords :
-        polcoords :
-        gridshape :
-        maxrange :
+        gridcoords : :class:`numpy:numpy.ndarray`
+            of shape (num voxels, 3)
+        polcoords : :class:`numpy:numpy.ndarray`
+            of shape (num bins, 3)
+        gridshape : tuple
+            shape of the Cartesian grid (num x, num y, num z)
+        maxrange : float
+            The maximum radar range
+            (must be the same for each elevation angle,
+            and same unit as gridcoords)
+        minelev : float
+            The minimum elevation angle of the volume (degree)
+        maxelev : float
+            The maximum elevation angle of the volume (degree)
 
         Returns
         -------
-        output : Boolean array of length (num voxels,)
+        output : :class:`numpy:numpy.ndarray`
+            Boolean array of length (num voxels,)
 
         """
         return np.repeat(False, len(gridcoords))
@@ -188,11 +206,11 @@ class CAPPI(CartesianVolume):
 
     Parameters
     ----------
-    polcoords : :func:`numpy:numpy.array` coordinate array \
-        of shape (num bins, 3)
+    polcoords : :class:`numpy:numpy.ndarray`
+        coordinate array of shape (num bins, 3)
         Represents the 3-D coordinates of the orginal radar bins
-    gridcoords : :func:`numpy:numpy.array` coordinate array \
-        of shape (num voxels, 3)
+    gridcoords : :func:`numpy:numpy.array`
+        coordinate array of shape (num voxels, 3)
         Represents the 3-D coordinates of the Cartesian grid
     gridshape : tuple
         shape of the original polar volume (num elevation angles,
@@ -200,17 +218,32 @@ class CAPPI(CartesianVolume):
         size must correspond to length of polcoords
     maxrange : float
         The maximum radar range (must be the same for each elevation angle)
-    Ipclass : an interpolation class from :mod:`wradlib.ipol`
-    ipargs : keyword arguments corresponding to Ipclass
+    ipclass : object
+        an interpolation class from :mod:`wradlib.ipol`
+    ipargs : `**kwargs`
+        keyword arguments corresponding to ``ipclass``
+
+    Returns
+    -------
+    output : :class:`numpy:numpy.ndarray`
+        float 1-d ndarray of the same length as ``gridcoords`` (num voxels,)
+
+    See Also
+    --------
+    out_of_range
+    blindspots
 
     Examples
     --------
-    See :ref:`notebooks/workflow/recipe2.ipynb`.
+    See :ref:`/notebooks/workflow/recipe2.ipynb`.
     """
 
     def _get_mask(self, gridcoords, polcoords, gridshape,
                   maxrange, minelev, maxelev):
-        """Masks the "blind" voxels of the Cartesian 3D-volume grid
+        """Masks the "blind" voxels of the Cartesian 3D-volume
+
+        For the CAPPI, blind voxels are below `minelev` and above `maxelev`
+        and beyond `maxrange`.
         """
         below, above, out_of_range = blindspots(self.radloc, gridcoords,
                                                 minelev, maxelev, maxrange)
@@ -221,8 +254,9 @@ class CAPPI(CartesianVolume):
 class PseudoCAPPI(CartesianVolume):
     """Create a Pseudo-CAPPI Constant Altitude Plan Position Indicator (CAPPI)
 
-    The difference to a CAPPI (:meth:`wradlib.vpr.CAPPI` is that the blind area
-    *below* and *above* the radar are not masked, but filled by interpolation.
+    The difference to a CAPPI (:class:`wradlib.vpr.CAPPI`) is that the blind
+    area *below* and *above* the radar are not masked, but filled by
+    interpolation.
     Only the areas beyond the *range* of the radar are masked out. As a result,
     "blind" areas below the radar are particularly filled from the lowest
     available elevation angle.
@@ -233,11 +267,11 @@ class PseudoCAPPI(CartesianVolume):
 
     Parameters
     ----------
-    polcoords : :func:`numpy:numpy.array` coordinate array \
-        of shape (num bins, 3)
+    polcoords : :class:`numpy:numpy.ndarray`
+        coordinate array of shape (num bins, 3)
         Represents the 3-D coordinates of the orginal radar bins
-    gridcoords : :func:`numpy:numpy.array` coordinate array \
-        of shape (num voxels, 3)
+    gridcoords : :class:`numpy:numpy.ndarray`
+        coordinate array of shape (num voxels, 3)
         Represents the 3-D coordinates of the Cartesian grid
     gridshape : tuple
         shape of the original polar volume (num elevation angles,
@@ -245,14 +279,30 @@ class PseudoCAPPI(CartesianVolume):
         size must correspond to length of polcoords
     maxrange : float
         The maximum radar range (must be the same for each elevation angle)
-    Ipclass : an interpolation class from :mod:`wradlib.ipol`
-    ipargs : keyword arguments corresponding to Ipclass
+    ipclass : object
+        an interpolation class from :mod:`wradlib.ipol`
+    ipargs : `**kwargs`
+        keyword arguments corresponding to ``ipclass``
 
+    Returns
+    -------
+    output : :class:`numpy:numpy.ndarray`
+        float 1-d ndarray of the same length as ``gridcoords`` (num voxels,)
+
+    See Also
+    --------
+    out_of_range
+
+    Examples
+    --------
+    See :ref:`/notebooks/workflow/recipe2.ipynb`.
     """
 
     def _get_mask(self, gridcoords, polcoords, gridshape,
                   maxrange, minelev, maxelev):
         """Masks the "blind" voxels of the Cartesian 3D-volume grid
+
+        For the Pseudo CAPPI, blind voxels are only those beyond `maxrange`.
         """
         return np.logical_not(np.logical_not(out_of_range(self.radloc,
                                                           gridcoords,
@@ -260,24 +310,28 @@ class PseudoCAPPI(CartesianVolume):
 
 
 def out_of_range(center, gridcoords, maxrange):
-    """Flags the region outside the radar range
+    """Masks the region outside the radar range
 
-    Paramters
+    Parameters
     ---------
-    center : radar location
-    gridcoords : array of 3-D coordinates with shape (num voxels, 3)
-    maxrange : maximum range (meters)
+    center : tuple
+        radar location
+    gridcoords : :class:`numpy:numpy.ndarray`
+        array of 3-D coordinates with shape (num voxels, 3)
+    maxrange : float
+        maximum range (same unit as gridcoords)
 
     Returns
     -------
-    output : 1-D Boolean array of length len(gridcoords)
+    output : :class:`numpy:numpy.ndarray`
+        1-D Boolean array of length len(gridcoords)
 
     """
     return ((gridcoords - center) ** 2).sum(axis=-1) > maxrange ** 2
 
 
 def blindspots(center, gridcoords, minelev, maxelev, maxrange):
-    """Blind regions of the radar, marked on a 3-D grid
+    """Masks blind regions of the radar, marked on a 3-D grid
 
     The radar is blind below the radar, above the radar and beyond the range.
     The function returns three boolean arrays which indicate whether (1) the
@@ -285,12 +339,17 @@ def blindspots(center, gridcoords, minelev, maxelev, maxrange):
     (3) the grid node is beyond the maximum range.
 
     Parameters
-    ----------
-    center
-    gridcoords
-    minelev
-    maxelev
-    maxrange
+    ---------
+    center : tuple
+        radar location
+    gridcoords : :class:`numpy:numpy.ndarray`
+        array of 3-D coordinates with shape (num voxels, 3)
+    minelev : float
+        The minimum elevation angle of the volume (degree)
+    maxelev : float
+        The maximum elevation angle of the volume (degree)
+    maxrange : float
+        maximum range (same unit as gridcoords)
 
     Returns
     -------
@@ -300,11 +359,12 @@ def blindspots(center, gridcoords, minelev, maxelev, maxrange):
     # distances of 3-D grid nodes from radar site (center)
     dist_from_rad = np.sqrt(((gridcoords - center) ** 2).sum(axis=-1))
     # below the radar
-    # TODO: use qual.beam_height_ft_doviak
-    below = gridcoords[:, 2] < (qual.beam_height_ft(dist_from_rad, minelev) +
+    below = gridcoords[:, 2] < (georef.bin_altitude(dist_from_rad, minelev, 0,
+                                                    re=6371000) +
                                 center[:, 2])
     # above the radar
-    above = gridcoords[:, 2] > (qual.beam_height_ft(dist_from_rad, maxelev) +
+    above = gridcoords[:, 2] > (georef.bin_altitude(dist_from_rad, maxelev, 0,
+                                                    re=6371000) +
                                 center[:, 2])
     # out of range
     out_of_range = dist_from_rad > maxrange
@@ -312,11 +372,7 @@ def blindspots(center, gridcoords, minelev, maxelev, maxrange):
 
 
 def volcoords_from_polar(sitecoords, elevs, azimuths, ranges, proj=None):
-    """
-    Create Cartesian coordinates for the polar volume bins
-
-    .. versionchanged:: 0.6.0
-       using osr objects instead of PROJ.4 strings as parameter
+    """Create Cartesian coordinates for regular polar volumes
 
     Parameters
     ----------
@@ -331,17 +387,17 @@ def volcoords_from_polar(sitecoords, elevs, azimuths, ranges, proj=None):
 
     Returns
     -------
-    output :  :func:`numpy:numpy.array`
+    output :  :class:`numpy:numpy.ndarray`
         (num volume bins, 3)
 
     Examples
     --------
-    See :ref:`notebooks/workflow/recipe2.ipynb`.
+    See :ref:`/notebooks/workflow/recipe2.ipynb`.
     """
     # make sure that elevs is an array
     elevs = np.array([elevs]).ravel()
     # create polar grid
-    el, az, r = util.meshgridN(elevs, azimuths, ranges)
+    el, az, r = util.meshgrid_n(elevs, azimuths, ranges)
 
     # get projected coordinates
     coords = georef.spherical_to_proj(r, az, el, sitecoords, proj=proj)
@@ -352,10 +408,8 @@ def volcoords_from_polar(sitecoords, elevs, azimuths, ranges, proj=None):
 
 def volcoords_from_polar_irregular(sitecoords, elevs, azimuths,
                                    ranges, proj=None):
-    """Create Cartesian coordinates for the polar volume bins
-
-    .. versionchanged:: 0.6.0
-       using osr objects instead of PROJ.4 strings as parameter
+    """Create Cartesian coordinates for polar volumes with irregular \
+    sweep specifications
 
     Parameters
     ----------
@@ -365,12 +419,12 @@ def volcoords_from_polar_irregular(sitecoords, elevs, azimuths,
     elevs : sequence of elevation angles
     azimuths : sequence of azimuth angles
     ranges : sequence of ranges
-    proj : osr spatial reference object
+    proj : object
         GDAL OSR Spatial Reference Object describing projection
 
     Returns
     -------
-    output : :func:`numpy:numpy.array`
+    output : :class:`numpy:numpy.ndarray`
         (num volume bins, 3)
 
     """
@@ -386,7 +440,7 @@ def volcoords_from_polar_irregular(sitecoords, elevs, azimuths,
         print("The following exception was raised:")
         raise
     assert (elevs.ndim == 1) and (elevs.dtype != np.dtype("object")), \
-        "Argument <elevs> in wradlib.wolcoords_from_polar must be a 1-D array."
+        "Argument <elevs> in wradlib.volcoords_from_polar must be a 1-D array."
     # now: is there one azimuths array for all elevation angles
     # or one for each?
     try:
@@ -446,31 +500,32 @@ def volcoords_from_polar_irregular(sitecoords, elevs, azimuths,
     return coords
 
 
-def make_3D_grid(sitecoords, proj, maxrange, maxalt, horiz_res, vert_res):
-    """Generate Cartesian coordinates for a regular 3-D grid based on
+def make_3d_grid(sitecoords, proj, maxrange, maxalt, horiz_res, vert_res):
+    """Generate Cartesian coordinates for a regular 3-D grid based on \
     radar specs.
 
-    .. versionchanged:: 0.6.0
-       using osr objects instead of PROJ.4 strings as parameter
-
     Parameters
     ----------
-    sitecoords
-    proj
-
-        .. versionadded:: 0.6.0
-           using osr objects instead of PROJ.4 strings as parameter
-
-    maxrange
-    maxalt
-    horiz_res
-    vert_res
+    sitecoords : tuple
+        Radar location coordinates in lon, lat
+    proj : object
+        GDAL OSR Spatial Reference Object describing projection
+    maxrange : float
+        maximum radar range (same unit as SRS defined by ``proj``,
+        typically meters)
+    maxalt : float
+        maximum altitude to which the 3-d grid should extent (meters)
+    horiz_res : float
+        horizontal resolution of the 3-d grid (same unit as
+        SRS defined by ``proj``, typically meters)
+    vert_res : float
+        vertical resolution of the 3-d grid (meters)
 
     Returns
     -------
-    output : float array of shape (num grid points, 3), a tuple of
+    output : :class:`numpy:numpy.ndarray`, tuple
+        float array of shape (num grid points, 3), a tuple of
         3 representing the grid shape
-
     """
     center = georef.reproject(sitecoords[0], sitecoords[1],
                               projection_target=proj)
@@ -486,43 +541,58 @@ def make_3D_grid(sitecoords, proj, maxrange, maxalt, horiz_res, vert_res):
 
 
 def synthetic_polar_volume(coords):
-    """Returns a synthetic polar volume
+    """Returns a totally arbitrary synthetic polar volume - just for testing
+
+    Parameters
+    ----------
+    coords : :class:`numpy:numpy.ndarray`
+        (num volume bins, 3), as returned by volcoords_from_polar
+
+    Returns
+    -------
+    output : :class:`numpy:numpy.ndarray`
+        float array of shape (num volume bins, 3)
     """
     x = coords[:, 0] * 10 / np.max(coords[:, 0])
     y = coords[:, 1] * 10 / np.max(coords[:, 1])
-    z = coords[:, 2] * 10 / np.max(coords[:, 2])
-    out = np.abs(np.sin(x * y * z) / (x * y * z))
+    z = coords[:, 2] / 1000.
+    out = np.abs(np.sin(x * y)) * np.exp(-z)
     out = out * 100. / out.max()
     return out
 
 
-def vpr_interpolator(data, heights, method='linear'):
-    """"""
-    if method.lower() == 'linear':
-        return scipy.interpolate.interp1d(heights, data, kind='linear')
-    if method.lower() == 'nearest':
-        return scipy.interpolate.interp1d(heights, data,
-                                          kind='nearest',
-                                          bounds_error=False,
-                                          fill_value=data[0])
-    else:
-        raise NotImplementedError('Method: {0:s} unkown'.format(method))
+def norm_vpr_stats(volume, reference_layer, stat=np.mean, **kwargs):
+    """Returns the average normalised vertical profile of a volume or \
+    any other desired statistics
 
+    Given a Cartesian 3-d ``volume`` and an arbitrary ``reference layer``
+    index, the function normalises all vertical profiles represented by the
+    volume and computes a static of all profiles (e.g. an average vertical
+    profile using the default ``stat``).
 
-def correct_vpr(data, heights, vpr, target_height=0.):
-    """"""
-    return (data * vpr(target_height)) / vpr(heights)
+    Parameters
+    ----------
+    volume : :class:`numpy:numpy.ndarray` or
+        :class:`numpy.ma.core.MaskedArray`
+        Cartesian 3-d grid with shape (num vertical layers, num x intervals,
+        num y intervals)
+    reference_layer : integer
+        This index defines the vertical layers of ``volume`` that is used to
+        normalise all vertical profiles
+    stat : function
+        typically a numpy statistics function (defaults to numpy.mean)
+    kwargs : further keyword arguments taken by ``stat``
 
+    Returns
+    -------
+    output : :class:`numpy:numpy.ndarray` or :class:`numpy.ma.core.MaskedArray`
+        of shape (num vertical layers,) which provides the statistic from
+        ``stat`` applied over all normalised vertical profiles (e.g. the
+        mean normalised vertical profile if numpy.mean is used)
 
-def mean_norm_vpr_from_volume(volume, reference_idx):
-    """"""
-    return norm_vpr_stats(volume, reference_idx, np.mean)
-
-
-def norm_vpr_stats(volume, reference_idx, stat, **kwargs):
-    # tmp = volume / volume[...,reference_idx]
-    tmp = volume / volume[reference_idx]
-    return stat(tmp.reshape((-1, np.prod(tmp.shape[-2:]))), **kwargs)
+    """
+    tmp = volume / volume[reference_layer]
+    return stat(tmp.reshape((-1, np.prod(tmp.shape[-2:]))), axis=1, **kwargs)
 
 
 if __name__ == '__main__':
