@@ -1,23 +1,23 @@
 #!/usr/bin/env python
-# Copyright (c) 2016, wradlib developers.
+# Copyright (c) 2011-2018, wradlib developers.
 # Distributed under the MIT License. See LICENSE.txt for more info.
 
 """
 Zonal Statistics
 ^^^^^^^^^^^^^^^^
 
-.. versionadded:: 0.7.0
-
 This module supports you in computing statistics over spatial zones. A typical
 application would be to compute mean areal precipitation for a catchment by
 using precipitation estimates from a radar grid in polar coordinates or from
 precipitation estimates in a Cartesian grid.
 
-The general usage is similar to the ipol and adjustment modules:
+The general usage is similar to the :mod:`wradlib.ipol` and
+:mod:`wradlib.adjust`:
 
-You have to create an instance of a class (derived from ZonalDataBase) by using
+You have to create an instance of a class (derived from
+:class:`~wradlib.zonalstats.ZonalDataBase`) by using
 the spatial information of your source and target objects (e.g. radar bins and
-catchment polygons). The Zonal Data within this object can be saved as an
+catchment polygons). The Zonal Data within this object can be saved eg. as an
 ESRI Shapefile.
 
 This object is then called with another class to compute zonal statistics for
@@ -44,8 +44,8 @@ Calling the objects with actual data, however, will be very fast.
    ZonalDataPoint
    ZonalDataPoly
    ZonalStatsBase
-   GridCellsToPoly
-   GridPointsToPoly
+   ZonalStatsPoly
+   ZonalStatsPoint
    mask_from_bbox
    get_bbox
    grid_centers_to_vertices
@@ -61,9 +61,8 @@ from osgeo import gdal, ogr
 import warnings
 
 from .io import open_vector, gdal_create_dataset, write_raster_dataset
-from .georef import (get_centroid, numpy_to_ogr, ogr_add_feature,
-                     ogr_add_geometry, ogr_copy_layer, ogr_create_layer,
-                     ogr_to_numpy, ogr_geocol_to_numpy, ogr_copy_layer_by_name)
+from .georef import (numpy_to_ogr, ogr_add_feature, ogr_copy_layer,
+                     ogr_create_layer, ogr_to_numpy, ogr_copy_layer_by_name)
 
 ogr.UseExceptions()
 gdal.UseExceptions()
@@ -72,8 +71,6 @@ gdal.UseExceptions()
 class DataSource(object):
     """ DataSource class for handling ogr/gdal vector data
 
-    .. versionadded:: 0.7.0
-
     DataSource handles creates in-memory (vector) ogr DataSource object with
     one layer for point or polygon geometries.
 
@@ -82,8 +79,8 @@ class DataSource(object):
     data : sequence of source points (shape Nx2) or polygons (shape NxMx2) or
         ESRI Shapefile filename containing source points/polygons
 
-    srs : ogr.SpatialReferenceSystem object
-        SRS describing projection of given data
+    srs : object
+        ogr.SpatialReferenceSystem SRS describing projection of given data
 
     Warning
     -------
@@ -92,8 +89,8 @@ class DataSource(object):
 
     Examples
     --------
-    See :ref:`notebooks/zonalstats/wradlib_zonalstats_classes.ipynb#\
-DataSource`.
+    See \
+    :ref:`/notebooks/zonalstats/wradlib_zonalstats_classes.ipynb#DataSource`.
     """
 
     def __init__(self, data=None, srs=None, **kwargs):
@@ -158,7 +155,7 @@ DataSource`.
         return np.array(sources)
 
     def get_data_by_att(self, attr=None, value=None):
-        """ Returns DataSource geometries filtered by given attribute/value
+        """Returns DataSource geometries filtered by given attribute/value
 
         Parameters
         ----------
@@ -174,7 +171,7 @@ DataSource`.
         return self._get_data()
 
     def get_data_by_geom(self, geom=None):
-        """ Returns DataSource geometries filtered by given OGR geometry
+        """Returns DataSource geometries filtered by given OGR geometry
 
         Parameters
         ----------
@@ -187,7 +184,7 @@ DataSource`.
         return self._get_data()
 
     def _check_src(self, src):
-        """ Basic check of source elements (sequence of points or polygons).
+        """Basic check of source elements (sequence of points or polygons).
 
             - array cast of source elements
             - create ogr_src datasource/layer holding src points/polygons
@@ -224,7 +221,7 @@ DataSource`.
         return ogr_src
 
     def dump_vector(self, filename, driver='ESRI Shapefile', remove=True):
-        """ Output layer to OGR Vector File
+        """Output layer to OGR Vector File
 
         Parameters
         ----------
@@ -246,7 +243,7 @@ DataSource`.
 
     def dump_raster(self, filename, driver='GTiff', attr=None,
                     pixel_size=1., remove=True):
-        """ Output layer to GDAL Rasterfile
+        """Output layer to GDAL Rasterfile
 
         Parameters
         ----------
@@ -298,7 +295,7 @@ DataSource`.
         del ds_out
 
     def set_attribute(self, name, values):
-        """ Add/Set given Attribute with given values
+        """Add/Set given Attribute with given values
 
         Parameters
         ----------
@@ -321,7 +318,7 @@ DataSource`.
             lyr.SetFeature(item)
 
     def get_attributes(self, attrs, filt=None):
-        """ Read attributes
+        """Read attributes
 
         Parameters
         ----------
@@ -341,12 +338,12 @@ DataSource`.
         return ret
 
     def get_geom_properties(self, props, filt=None):
-        """ Read attributes
+        """Read properties
 
         Parameters
         ----------
         props : list
-            Attribute Names to retrieve
+            Property Names to retrieve
         filt : tuple
             (attname,value) for Attribute Filter
 
@@ -363,10 +360,10 @@ DataSource`.
 
 
 class ZonalDataBase(object):
-    """
-    The base class for managing 2-dimensional zonal data for target polygons
-    from source points or polygons. Provides the basic design for all other
-    classes.
+    """Base class for managing 2-dimensional zonal data.
+
+    For target polygons from either source points or source polygons.
+    Provides the basic design for all other classes.
 
     If no source points or polygons can be associated to a target polygon (e.g.
     no intersection), the created destination layer will be empty.
@@ -380,8 +377,6 @@ class ZonalDataBase(object):
 
     By using OGR there are no restrictions for the used source grids.
 
-    .. versionadded:: 0.7.0
-
     Warning
     -------
     Writing shapefiles with the wrong locale settings can have impact on the
@@ -391,7 +386,6 @@ class ZonalDataBase(object):
     ----------
     src : sequence of source points (shape Nx2) or polygons (shape NxMx2) or
         ESRI Shapefile filename containing source points/polygons
-
     trg : sequence of target polygons (shape Nx2, num vertices x 2) or
         ESRI Shapefile filename containing target polygons
 
@@ -402,13 +396,15 @@ class ZonalDataBase(object):
         Points/Polygons  will be considered inside the target if they are
         contained in the buffer.
 
-    srs : OGR.SpatialReference
+    srs : object
+        OGR.SpatialReference
         will be used for DataSource object.
         src and trg data have to be in the same srs-format
 
     Examples
     --------
-    See :ref:`notebooks/zonalstats/wradlib_zonalstats_classes.ipynb#ZonalData`.
+    See \
+    :ref:`/notebooks/zonalstats/wradlib_zonalstats_classes.ipynb#ZonalData`.
 
     """
     def __init__(self, src, trg=None, buf=0., srs=None, **kwargs):
@@ -425,19 +421,19 @@ class ZonalDataBase(object):
 
     @property
     def count_intersections(self):
-        """ Returns number of intersections
+        """Returns number of intersections
         """
         return self._count_intersections
 
     @property
     def srs(self):
-        """ Returns SpatialReferenceSystem object
+        """Returns SpatialReferenceSystem object
         """
         return self._srs
 
     @property
     def isecs(self):
-        """ Returns intersections
+        """Returns intersections
 
         Returns
         -------
@@ -449,7 +445,7 @@ class ZonalDataBase(object):
                                           GetFeatureCount())])
 
     def get_isec(self, idx):
-        """ Returns intersections
+        """Returns intersections
 
         Parameters
         ----------
@@ -464,7 +460,7 @@ class ZonalDataBase(object):
         return self._get_intersection(idx=idx)
 
     def get_source_index(self, idx):
-        """ Returns source indices referring to target polygon idx
+        """Returns source indices referring to target polygon idx
 
         Parameters
         ----------
@@ -479,19 +475,17 @@ class ZonalDataBase(object):
         return np.array(self.dst.get_attributes(['src_index'],
                                                 filt=('trg_index', idx))[0])
 
-    def _create_dst_datasource(self, **kwargs):
-        """ Create destination target gdal.Dataset
+    def _create_dst_datasource(self):
+        """Create destination target gdal.Dataset
 
         Creates one layer for each target polygon, consisting of
         the needed source data attributed with index and weights fields
 
         Returns
         -------
-        ds_mem : gdal.Dataset object
+        ds_mem : object
+            gdal.Dataset object
         """
-
-        # TODO: kwargs necessary?
-
         # create intermediate mem dataset
         ds_mem = gdal_create_dataset('Memory', 'dst',
                                      gdal_type=gdal.OF_VECTOR)
@@ -540,13 +534,8 @@ class ZonalDataBase(object):
 
         return ds_mem
 
-    def _create_dst_features(self, dst, trg, **kwargs):
-        """ Create OGR.Features in Destination OGR.Layer
-        """
-        raise NotImplementedError
-
     def dump_vector(self, filename, driver='ESRI Shapefile', remove=True):
-        """ Output source/target grid points/polygons to ESRI_Shapefile
+        """Output source/target grid points/polygons to ESRI_Shapefile
 
         target layer features are attributed with source index and weight
 
@@ -564,7 +553,7 @@ class ZonalDataBase(object):
         self.dst.dump_vector(filename, driver, remove=False)
 
     def load_vector(self, filename):
-        """ Load source/target grid points/polygons into in-memory Shapefile
+        """Load source/target grid points/polygons into in-memory Shapefile
 
         Parameters
         ----------
@@ -600,7 +589,7 @@ class ZonalDataBase(object):
         del ds_in
 
     def _get_idx_weights(self):
-        """ Retrieve index and weight from dst DataSource
+        """Retrieve index and weight from dst DataSource
         """
         raise NotImplementedError
 
@@ -635,7 +624,7 @@ class ZonalDataBase(object):
         trg = trg.Buffer(buf)
 
         if idx is None:
-            intersecs = self.src.get_data_by_geom(trg)
+            intersecs = self.dst.get_data_by_geom(trg)
         else:
             intersecs = self.dst.get_data_by_att('trg_index', idx)
 
@@ -643,9 +632,7 @@ class ZonalDataBase(object):
 
 
 class ZonalDataPoly(ZonalDataBase):
-    """ ZonalData object for source polygons
-
-    .. versionadded:: 0.7.0
+    """ZonalData object for source polygons
 
     Parameters
     ----------
@@ -662,26 +649,26 @@ class ZonalDataPoly(ZonalDataBase):
         Polygons will be considered inside the target if they are contained
         in the buffer.
 
-    srs : OGR.SpatialReference
+    srs : object
+        OGR.SpatialReference
         will be used for DataSource object.
         src and trg data have to be in the same srs-format
 
     Examples
     --------
-    See :ref:`notebooks/zonalstats/wradlib_zonalstats_classes.ipynb#ZonalData`.
+    See \
+    :ref:`/notebooks/zonalstats/wradlib_zonalstats_classes.ipynb#ZonalData`.
     """
     def _get_idx_weights(self):
-        """ Retrieve index and weight from dst DataSource
+        """Retrieve index and weight from dst DataSource
 
         Iterates over all trg DataSource Polygons
 
         Returns
         -------
-
         ret : tuple
             (index, weight) arrays
-
-        """
+       """
         trg = self.trg.ds.GetLayer()
         cnt = trg.GetFeatureCount()
         ret = [[] for _ in range(2)]
@@ -695,61 +682,14 @@ class ZonalDataPoly(ZonalDataBase):
                 ret[i].append(np.array(l))
         return tuple(ret)
 
-    def _create_dst_features(self, dst, trg, **kwargs):
-        """ Create needed OGR.Features in dst OGR.Layer
-
-        Parameters
-        ----------
-        dst : OGR.Layer
-            destination layer
-        trg : OGR.Geometry
-            target polygon
-        """
-        # TODO: kwargs necessary?
-
-        # claim and reset source ogr layer
-        layer = self.src.ds.GetLayerByName('src')
-        layer.ResetReading()
-
-        # if given, we apply a buffer value to the target polygon filter
-        trg_index = trg.GetField('index')
-        trg = trg.GetGeometryRef()
-        trg = trg.Buffer(self._buffer)
-        layer.SetSpatialFilter(trg)
-
-        # iterate over layer features
-        for ogr_src in layer:
-            geom = ogr_src.GetGeometryRef()
-
-            # calculate intersection, if not fully contained
-            if not trg.Contains(geom):
-                geom = trg.Intersection(geom)
-
-            # checking GeometryCollection, convert to only Polygons,
-            #  Multipolygons
-            if geom.GetGeometryType() in [7]:
-                geocol = ogr_geocol_to_numpy(geom)
-                geom = numpy_to_ogr(geocol, 'MultiPolygon')
-
-            # only geometries containing points
-            if geom.IsEmpty():
-                continue
-
-            if geom.GetGeometryType() in [3, 6, 12]:
-                idx = ogr_src.GetField('index')
-                ogr_add_geometry(dst, geom, [idx, trg_index])
-
 
 class ZonalDataPoint(ZonalDataBase):
-    """ ZonalData object for source points
-
-    .. versionadded:: 0.7.0
+    """ZonalData object for source points
 
     Parameters
     ----------
     src : sequence of source points (shape Nx2) or
         ESRI Shapefile filename containing source points
-
     trg : sequence of target polygons (shape Nx2, num vertices x 2) or
         ESRI Shapefile filename containing target polygons
 
@@ -760,16 +700,18 @@ class ZonalDataPoint(ZonalDataBase):
         Points will be considered inside the target if they are contained
         in the buffer.
 
-    srs : OGR.SpatialReference
+    srs : object
+        OGR.SpatialReference
         will be used for DataSource object.
         src and trg data have to be in the same srs-format
 
     Examples
     --------
-    See :ref:`notebooks/zonalstats/wradlib_zonalstats_classes.ipynb#ZonalData`.
+    See \
+    :ref:`/notebooks/zonalstats/wradlib_zonalstats_classes.ipynb#ZonalData`.
     """
     def _get_idx_weights(self):
-        """ Retrieve index and weight from dst DataSource
+        """Retrieve index and weight from dst DataSource
 
         Iterates over all trg DataSource Polygons
 
@@ -789,51 +731,10 @@ class ZonalDataPoint(ZonalDataBase):
                 ret[i].append(np.array(l))
         return tuple(ret)
 
-    def _create_dst_features(self, dst, trg, **kwargs):
-        """ Create needed OGR.Features in dst OGR.Layer
-
-        Parameters
-        ----------
-        dst : OGR.Layer
-            destination layer
-        trg : OGR.Geometry
-            target polygon
-        """
-        # TODO: kwargs necessary?
-
-        # claim and reset source ogr layer
-        layer = self.src.ds.GetLayerByName('src')
-        layer.ResetReading()
-
-        # if given, we apply a buffer value to the target polygon filter
-        trg_index = trg.GetField('index')
-        trg = trg.GetGeometryRef()
-        trg = trg.Buffer(self._buffer)
-        layer.SetSpatialFilter(trg)
-
-        feat_cnt = layer.GetFeatureCount()
-
-        if feat_cnt:
-            [ogr_add_geometry(dst, ogr_src.GetGeometryRef(),
-                              [ogr_src.GetField('index'), trg_index])
-             for ogr_src in layer]
-        else:
-            layer.SetSpatialFilter(None)
-            src_pts = np.array([ogr_src.GetGeometryRef().GetPoint_2D(0)
-                                for ogr_src in layer])
-            centroid = get_centroid(trg)
-            tree = cKDTree(src_pts)
-            distnext, ixnext = tree.query([centroid[0], centroid[1]], k=1)
-            feat = layer.GetFeature(ixnext)
-            ogr_add_geometry(dst, feat.GetGeometryRef(),
-                             [feat.GetField('index'), trg_index])
-
 
 class ZonalStatsBase(object):
     """Base class for all 2-dimensional zonal statistics.
 
-    .. versionadded:: 0.7.0
-
     The base class for computing 2-dimensional zonal statistics for target
     polygons from source points or polygons as built up with ZonalDataBase
     and derived classes. Provides the basic design for all other classes.
@@ -843,15 +744,15 @@ class ZonalStatsBase(object):
 
     Parameters
     ----------
-    src : ZonalDataPoly
-        object or filename pointing to ZonalDataPoly ESRI shapefile
-        containing necessary ZonalData
-        ZonalData is available as 'zdata'-property inside class instance.
+    src : object | string
+        ZonalDataPoly object or filename pointing to ZonalDataPoly ESRI
+        shapefile containing necessary ZonalData
+        ZonalData is available as ``zdata``-property inside class instance.
 
     Examples
     --------
-    See :ref:`notebooks/zonalstats/wradlib_zonalstats_classes.ipynb#\
-ZonalStats`.
+    See \
+    :ref:`/notebooks/zonalstats/wradlib_zonalstats_classes.ipynb#ZonalStats`.
     """
     def __init__(self, src=None, ix=None, w=None):
 
@@ -914,9 +815,8 @@ ZonalStats`.
                 raise TypeError("parameters ix and w must be of equal length")
             return np.array(ix), np.array(w)
         else:
-            print("ix and w are complementary parameters and "
-                  "must both be given")
-            raise TypeError
+            raise TypeError("ix and w are complementary parameters and "
+                            "must both be given")
 
     def _check_vals(self, vals):
         """TODO Basic check of target elements (sequence of polygons).
@@ -941,13 +841,13 @@ ZonalStats`.
         return vals
 
     def mean(self, vals):
-        """
-        Evaluate (weighted) zonal mean for values given at the source points.
+        """Evaluate (weighted) zonal mean for values given at the source \
+        points.
 
         Parameters
         ----------
-        vals : 1-d :class:`numpy:numpy.ndarray`
-            of type float with the same length as self.src
+        vals : :class:`numpy:numpy.ndarray`
+            1-d array of type float with the same length as self.src
             Values at the source element for which to compute zonal statistics
 
         """
@@ -964,14 +864,13 @@ ZonalStats`.
         return out
 
     def var(self, vals):
-        """
-        Evaluate (weighted) zonal variance for values given at the source
+        """Evaluate (weighted) zonal variance for values given at the source \
         points.
 
         Parameters
         ----------
-        vals : 1-d :class:`numpy:numpy.ndarray`
-            of type float with the same length as self.src
+        vals : :class:`numpy:numpy.ndarray`
+            1-d  array of type float with the same length as self.src
             Values at the source element for which to compute
             zonal statistics
 
@@ -989,74 +888,68 @@ ZonalStats`.
         return out
 
 
-# should we rename class?
-# GridCellStats ?
-class GridCellsToPoly(ZonalStatsBase):
+class ZonalStatsPoly(ZonalStatsBase):
     """Compute weighted average for target polygons based on areal weights.
 
-    .. versionadded:: 0.7.0
-
     Parameters
     ----------
-    src : ZonalDataPoly
-        object or filename pointing to ZonalDataPoly ESRI shapefile
-        containing necessary Zonal Data
+    src : :class:`~wradlib.zonalstats.ZonalDataPoly` | str
+        ZonalDataPoly object or filename pointing to ZonalDataPoly ESRI
+        shapefile containing necessary Zonal Data
 
     Keyword arguments
     -----------------
 
     Examples
     --------
-    See :ref:`notebooks/zonalstats/wradlib_zonalstats_classes.ipynb#ZonalStats`
-    and :ref:`notebooks/zonalstats/wradlib_zonalstats_example.ipynb`.
+    See \
+    :ref:`/notebooks/zonalstats/wradlib_zonalstats_classes.ipynb#ZonalStats`
+    and :ref:`/notebooks/zonalstats/wradlib_zonalstats_example.ipynb`.
     """
     def __init__(self, src=None, **kwargs):
         if src is not None:
             if not isinstance(src, ZonalDataPoly):
                 src = ZonalDataPoly(src, **kwargs)
-        super(GridCellsToPoly, self).__init__(src, **kwargs)
+        super(ZonalStatsPoly, self).__init__(src, **kwargs)
 
 
-# should we rename class?
-# GridPointStats ?
-class GridPointsToPoly(ZonalStatsBase):
+class ZonalStatsPoint(ZonalStatsBase):
     """Compute zonal average from all points in or close to the target polygon.
 
-    .. versionadded:: 0.7.0
-
     Parameters
     ----------
-    src : ZonalDataPoint
-        object or filename pointing to ZonalDataPoly ESRI shapefile
-        containing necessary Zonal Data
+    src : :class:`~wradlib.zonalstats.ZonalDataPoint` | str
+        ZonalDataPoint object or filename pointing to ZonalDataPoly ESRI
+        shapefile containing necessary Zonal Data
 
     Keyword arguments
     -----------------
 
     Examples
     --------
-    See :ref:`notebooks/zonalstats/wradlib_zonalstats_classes.ipynb#ZonalStats`
-    and :ref:`notebooks/zonalstats/wradlib_zonalstats_example.ipynb`.
+    See \
+    :ref:`/notebooks/zonalstats/wradlib_zonalstats_classes.ipynb#ZonalStats`
+    and :ref:`/notebooks/zonalstats/wradlib_zonalstats_example.ipynb`.
     """
     def __init__(self, src, **kwargs):
         if src is not None:
             if not isinstance(src, ZonalDataPoint):
                 src = ZonalDataPoint(src, **kwargs)
-        super(GridPointsToPoly, self).__init__(src, **kwargs)
+        super(ZonalStatsPoint, self).__init__(src, **kwargs)
 
 
 def numpy_to_pathpatch(arr):
-    """ Returns PathPatches from nested array
+    """Returns PathPatches from nested array
 
     Parameters
     ----------
     arr : :class:`numpy:numpy.ndarray`
-        numpy array of Polygon/Multipolygon vertices
+        array of Polygon/Multipolygon vertices
 
     Returns
     -------
     array : :class:`numpy:numpy.ndarray`
-        of matplotlib.patches.PathPatch objects
+        array of matplotlib.patches.PathPatch objects
     """
     paths = []
     for item in arr:
@@ -1080,16 +973,12 @@ def mask_from_bbox(x, y, bbox, polar=False):
     Use this function to create a 2-d boolean mask from 2-d arrays of grids
     points.
 
-    .. versionadded:: 0.7.0
-
     Parameters
     ----------
     x : :class:`numpy:numpy.ndarray`
-        of shape (num rows, num columns)
-        x (Cartesian) coordinates
+        x (Cartesian) coordinates of shape (num rows, num columns)
     y : :class:`numpy:numpy.ndarray`
-        of shape (num rows, num columns)
-        y (Cartesian) coordinates
+        y (Cartesian) coordinates of shape (num rows, num columns)
     bbox : dict
         dictionary with keys "left", "right", "bottom", "top"
         These must refer to the same Cartesian reference system as x and y
@@ -1098,9 +987,9 @@ def mask_from_bbox(x, y, bbox, polar=False):
 
     Returns
     -------
-    out : mask, shape
-          mask is a boolean array that is True if the point is inside the bbox
-          shape is the shape of the True subgrid
+    mask, shape : :class:`numpy:numpy.ndarray`, tuple
+              mask is a boolean array that is True if the point is inside the
+              bbox, shape is the shape of the True subgrid
 
     """
     ny, nx = x.shape
@@ -1215,8 +1104,10 @@ def grid_centers_to_vertices(x, y, dx, dy):
         2-d array of x coordinates (same shape as the actual 2-D grid)
     y : :class:`numpy:numpy.ndarray`
         2-d array of y coordinates (same shape as the actual 2-D grid)
-    dx : grid spacing in x direction
-    dy : grid spacing in y direction
+    dx : float
+        grid spacing in x direction
+    dy : float
+        grid spacing in y direction
 
     Returns
     -------
@@ -1238,20 +1129,17 @@ def grid_centers_to_vertices(x, y, dx, dy):
 
 
 def get_clip_mask(coords, clippoly, srs=None):
-    """Returns boolean mask of points (coords) located inside polygon clippoly
-
-    .. versionadded:: 0.10.0
+    """Returns boolean mask of points ``coords`` inside polygon ``clippoly``
 
     Parameters
     ----------
     coords : :class:`numpy:numpy.ndarray`
         array of xy coords with shape [...,2]
-
     clippoly : :class:`numpy:numpy.ndarray`
         array of xy coords with shape (N,2) representing closed
         polygon coordinates
-
-    srs: osr.SpatialReference
+    srs: object
+        osr.SpatialReference
 
     Returns
     -------
@@ -1268,7 +1156,7 @@ def get_clip_mask(coords, clippoly, srs=None):
     src_mask = np.zeros(coords.shape[0:-1], dtype=np.bool)
 
     try:
-        obj = GridPointsToPoly(zd)
+        obj = ZonalStatsPoint(zd)
 
         # Get source indices within polygon from zonal object
         # (0 because we have only one zone)
